@@ -15,6 +15,8 @@ import junit.framework.Test;
 import junit.framework.TestSuite;
 
 import org.eclipse.mylyn.builds.tests.core.BuildModelManagerTest;
+import org.eclipse.mylyn.builds.tests.operations.RefreshOperationTest;
+import org.eclipse.mylyn.builds.tests.util.BuildsUrlHandlerTest;
 import org.eclipse.mylyn.builds.tests.util.JUnitResultGeneratorTest;
 
 /**
@@ -27,9 +29,11 @@ public class AllBuildsTests {
 	}
 
 	public static Test suite(boolean defaultOnly) {
-		TestSuite suite = new TestSuite("Tests for org.eclipse.mylyn.builds.tests");
+		TestSuite suite = new TestSuite(AllBuildsTests.class.getName());
 		suite.addTestSuite(BuildModelManagerTest.class);
 		suite.addTestSuite(JUnitResultGeneratorTest.class);
+		suite.addTestSuite(RefreshOperationTest.class);
+		suite.addTestSuite(BuildsUrlHandlerTest.class);
 		return suite;
 	}
 
