@@ -36,16 +36,17 @@ import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.ParserConfigurationException;
 
-import org.apache.commons.httpclient.Header;
-import org.apache.commons.httpclient.HttpStatus;
-import org.apache.commons.httpclient.NameValuePair;
+import org.apache.http.Header;
+import org.apache.http.HttpStatus;
+import org.apache.http.client.methods.HttpPost;
+import org.apache.http.client.methods.HttpRequestBase;
 import org.eclipse.core.runtime.Assert;
 import org.eclipse.mylyn.builds.core.spi.AbstractConfigurationCache;
-import org.eclipse.mylyn.commons.core.IOperationMonitor;
-import org.eclipse.mylyn.commons.http.CommonHttpClient;
-import org.eclipse.mylyn.commons.http.CommonHttpMethod;
-import org.eclipse.mylyn.commons.net.AbstractWebLocation;
-import org.eclipse.mylyn.internal.commons.http.CommonPostMethod;
+import org.eclipse.mylyn.commons.core.operations.IOperationMonitor;
+import org.eclipse.mylyn.commons.repositories.core.RepositoryLocation;
+import org.eclipse.mylyn.commons.repositories.http.core.CommonHttpClient;
+import org.eclipse.mylyn.commons.repositories.http.core.CommonHttpResponse;
+import org.eclipse.mylyn.internal.hudson.core.client.HudsonServerInfo.Type;
 import org.eclipse.mylyn.internal.hudson.model.HudsonMavenReportersSurefireAggregatedReport;
 import org.eclipse.mylyn.internal.hudson.model.HudsonModelBuild;
 import org.eclipse.mylyn.internal.hudson.model.HudsonModelHudson;
@@ -61,8 +62,6 @@ import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 import org.xml.sax.SAXException;
 
-import com.google.gson.Gson;
-
 /**
  * Represents the Hudson repository that is accessed through REST.
  * 
@@ -101,28 +100,14 @@ public class RestfulHudsonClient {
 
 	private final CommonHttpClient client;
 
-	public RestfulHudsonClient(AbstractWebLocation location, HudsonConfigurationCache cache) {
+	private volatile HudsonServerInfo info;
+
+	public RestfulHudsonClient(RepositoryLocation location, HudsonConfigurationCache cache) {
+		// FIXME register listener to location to handle credential changes
 		client = new CommonHttpClient(location);
-		client.getHttpClient().getParams().setAuthenticationPreemptive(true);
 		setCache(cache);
 	}
 
-	protected void checkResponse(CommonHttpMethod method) throws HudsonException {
-		checkResponse(method, HttpStatus.SC_OK);
-	}
-
-	protected void checkResponse(CommonHttpMethod method, int expected) throws HudsonException {
-		int statusCode = method.getStatusCode();
-		if (statusCode != expected) {
-			if (statusCode == HttpStatus.SC_NOT_FOUND) {
-				throw new HudsonResourceNotFoundException(NLS.bind("Requested resource ''{0}'' does not exist",
-						method.getPath()));
-			}
-			throw new HudsonException(NLS.bind("Unexpected response from Hudson server for ''{0}'': {1}",
-					method.getPath(), HttpStatus.getStatusText(statusCode)));
-		}
-	}
-
 	public List<HudsonModelRun> getBuilds(final HudsonModelJob job, final IOperationMonitor monitor)
 			throws HudsonException {
 		return new HudsonOperation<List<HudsonModelRun>>(client) {
@@ -132,17 +117,17 @@ public class RestfulHudsonClient {
 						.depth(1)
 						.tree("builds[number,url,building,result,duration,timestamp,actions[causes[shortDescription],failCount,totalCount,skipCount]]")
 						.toUrl();
-				CommonHttpMethod method = createGetMethod(url);
-				try {
-					execute(method, monitor);
-					checkResponse(method);
-					InputStream in = method.getResponseBodyAsStream(monitor);
+				HttpRequestBase request = createGetRequest(url);
+				CommonHttpResponse response = execute(request, monitor);
+				return processAndRelease(response, monitor);
+			}
 
-					HudsonModelProject project = unmarshal(parse(in, url), HudsonModelProject.class);
-					return project.getBuild();
-				} finally {
-					method.releaseConnection(monitor);
-				}
+			@Override
+			protected List<HudsonModelRun> doProcess(CommonHttpResponse response, IOperationMonitor monitor)
+					throws IOException, HudsonException, JAXBException {
+				InputStream in = response.getResponseEntityAsStream(monitor);
+				HudsonModelProject project = unmarshal(parse(in, response.getRequestPath()), HudsonModelProject.class);
+				return project.getBuild();
 			}
 		}.run();
 	}
@@ -153,16 +138,17 @@ public class RestfulHudsonClient {
 			@Override
 			public HudsonModelBuild execute() throws IOException, HudsonException, JAXBException {
 				String url = getBuildUrl(job, build) + URL_API;
-				CommonHttpMethod method = createGetMethod(url);
-				try {
-					execute(method, monitor);
-					checkResponse(method);
-					InputStream in = method.getResponseBodyAsStream(monitor);
-					HudsonModelBuild hudsonBuild = unmarshal(parse(in, url), HudsonModelBuild.class);
-					return hudsonBuild;
-				} finally {
-					method.releaseConnection(monitor);
-				}
+				HttpRequestBase request = createGetRequest(url);
+				CommonHttpResponse response = execute(request, monitor);
+				return processAndRelease(response, monitor);
+			}
+
+			@Override
+			protected HudsonModelBuild doProcess(CommonHttpResponse response, IOperationMonitor monitor)
+					throws IOException, HudsonException, JAXBException {
+				InputStream in = response.getResponseEntityAsStream(monitor);
+				HudsonModelBuild hudsonBuild = unmarshal(parse(in, response.getRequestPath()), HudsonModelBuild.class);
+				return hudsonBuild;
 			}
 		}.run();
 	}
@@ -181,26 +167,27 @@ public class RestfulHudsonClient {
 				String url = HudsonUrl.create(getBuildUrl(job, build) + "/testReport")
 						.tree(resultTree + "," + aggregatedTree)
 						.toUrl();
-				CommonHttpMethod method = createGetMethod(url);
-				try {
-					execute(method, monitor);
-					checkResponse(method);
-					InputStream in = method.getResponseBodyAsStream(monitor);
-					Element element = parse(in, url);
-					if ("surefireAggregatedReport".equals(element.getNodeName())) {
-						HudsonMavenReportersSurefireAggregatedReport report = unmarshal(element,
-								HudsonMavenReportersSurefireAggregatedReport.class);
-						// unmarshal nested test results
-						for (HudsonTasksTestAggregatedTestResultActionChildReport child : report.getChildReport()) {
-							child.setResult(RestfulHudsonClient.unmarshal((Node) child.getResult(),
-									HudsonTasksJunitTestResult.class));
-						}
-						return new HudsonTestReport(report);
+				HttpRequestBase request = createGetRequest(url);
+				CommonHttpResponse response = execute(request, monitor);
+				return processAndRelease(response, monitor);
+			}
+
+			@Override
+			protected HudsonTestReport doProcess(CommonHttpResponse response, IOperationMonitor monitor)
+					throws IOException, HudsonException, JAXBException {
+				InputStream in = response.getResponseEntityAsStream(monitor);
+				Element element = parse(in, response.getRequestPath());
+				if ("surefireAggregatedReport".equals(element.getNodeName())) {
+					HudsonMavenReportersSurefireAggregatedReport report = unmarshal(element,
+							HudsonMavenReportersSurefireAggregatedReport.class);
+					// unmarshal nested test results
+					for (HudsonTasksTestAggregatedTestResultActionChildReport child : report.getChildReport()) {
+						child.setResult(RestfulHudsonClient.unmarshal((Node) child.getResult(),
+								HudsonTasksJunitTestResult.class));
 					}
-					return new HudsonTestReport(unmarshal(element, HudsonTasksJunitTestResult.class));
-				} finally {
-					method.releaseConnection(monitor);
+					return new HudsonTestReport(report);
 				}
+				return new HudsonTestReport(unmarshal(element, HudsonTasksJunitTestResult.class));
 			}
 		}.run();
 	}
@@ -230,15 +217,21 @@ public class RestfulHudsonClient {
 			final IOperationMonitor monitor) throws HudsonException {
 		return new HudsonOperation<Reader>(client) {
 			@Override
-			public Reader execute() throws IOException, HudsonException {
-				CommonHttpMethod method = createGetMethod(getBuildUrl(job, hudsonBuild) + "/consoleText");
-				execute(method, monitor);
-				checkResponse(method);
-				String charSet = method.getResponseCharSet();
+			public Reader execute() throws IOException, HudsonException, JAXBException {
+				HttpRequestBase request = createGetRequest(getBuildUrl(job, hudsonBuild) + "/consoleText");
+				CommonHttpResponse response = execute(request, monitor);
+				return process(response, monitor);
+			}
+
+			@Override
+			protected Reader doProcess(CommonHttpResponse response, IOperationMonitor monitor) throws IOException,
+					HudsonException {
+				InputStream in = response.getResponseEntityAsStream(monitor);
+				String charSet = response.getResponseCharSet();
 				if (charSet == null) {
 					charSet = "UTF-8";
 				}
-				return new InputStreamReader(method.getResponseBodyAsStream(monitor), charSet);
+				return new InputStreamReader(in, charSet);
 			}
 		}.run();
 	}
@@ -261,40 +254,41 @@ public class RestfulHudsonClient {
 						.match("name", ids)
 						.exclude("/hudson/job/build")
 						.toUrl();
-				CommonHttpMethod method = createGetMethod(url);
-				try {
-					execute(method, monitor);
-					checkResponse(method);
-					InputStream in = method.getResponseBodyAsStream(monitor);
+				HttpRequestBase request = createGetRequest(url);
+				CommonHttpResponse response = execute(request, monitor);
+				return processAndRelease(response, monitor);
+			}
 
-					Map<String, String> jobNameById = new HashMap<String, String>();
+			@Override
+			protected List<HudsonModelJob> doProcess(CommonHttpResponse response, IOperationMonitor monitor)
+					throws IOException, HudsonException, JAXBException {
+				InputStream in = response.getResponseEntityAsStream(monitor);
 
-					HudsonModelHudson hudson = unmarshal(parse(in, url), HudsonModelHudson.class);
+				Map<String, String> jobNameById = new HashMap<String, String>();
 
-					List<HudsonModelJob> buildPlans = new ArrayList<HudsonModelJob>();
-					List<Object> jobsNodes = hudson.getJob();
-					for (Object jobNode : jobsNodes) {
-						Node node = (Node) jobNode;
-						HudsonModelJob job = unmarshal(node, HudsonModelJob.class);
-						if (job.getDisplayName() != null && job.getDisplayName().length() > 0) {
-							jobNameById.put(job.getName(), job.getDisplayName());
-						} else {
-							jobNameById.put(job.getName(), job.getName());
-						}
-						buildPlans.add(job);
+				HudsonModelHudson hudson = unmarshal(parse(in, response.getRequestPath()), HudsonModelHudson.class);
+
+				List<HudsonModelJob> buildPlans = new ArrayList<HudsonModelJob>();
+				List<Object> jobsNodes = hudson.getJob();
+				for (Object jobNode : jobsNodes) {
+					Node node = (Node) jobNode;
+					HudsonModelJob job = unmarshal(node, HudsonModelJob.class);
+					if (job.getDisplayName() != null && job.getDisplayName().length() > 0) {
+						jobNameById.put(job.getName(), job.getDisplayName());
+					} else {
+						jobNameById.put(job.getName(), job.getName());
 					}
-
-					if (ids == null) {
-						// update list of known jobs if all jobs were retrieved
-						HudsonConfiguration configuration = new HudsonConfiguration();
-						configuration.jobNameById = jobNameById;
-						setConfiguration(configuration);
-					}
-
-					return buildPlans;
-				} finally {
-					method.releaseConnection(monitor);
+					buildPlans.add(job);
 				}
+
+				if (ids == null) {
+					// update list of known jobs if all jobs were retrieved
+					HudsonConfiguration configuration = new HudsonConfiguration();
+					configuration.jobNameById = jobNameById;
+					setConfiguration(configuration);
+				}
+
+				return buildPlans;
 			}
 		}.run();
 	}
@@ -323,77 +317,50 @@ public class RestfulHudsonClient {
 		return new HudsonOperation<Document>(client) {
 			@Override
 			public Document execute() throws IOException, HudsonException, JAXBException {
-				CommonHttpMethod method = createGetMethod(getJobUrl(job) + "/config.xml");
-				try {
-					execute(method, monitor);
-					checkResponse(method);
+				HttpRequestBase request = createGetRequest(getJobUrl(job) + "/config.xml");
+				CommonHttpResponse response = execute(request, monitor);
+				return processAndRelease(response, monitor);
+			}
 
-					InputStream in = method.getResponseBodyAsStream(monitor);
+			@Override
+			protected Document doProcess(CommonHttpResponse response, IOperationMonitor monitor) throws IOException,
+					HudsonException, JAXBException {
+				InputStream in = response.getResponseEntityAsStream(monitor);
+				try {
 					DocumentBuilder builder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
 					return builder.parse(in); // TODO Enhance progress monitoring
 				} catch (ParserConfigurationException e) {
 					throw new HudsonException(e);
 				} catch (SAXException e) {
 					throw new HudsonException(e);
-				} finally {
-					method.releaseConnection(monitor);
 				}
 			}
 		}.run();
 	}
 
-	private class Parameters {
-
-		private NameValue[] parameter;
-	}
-
-	private static class NameValue {
-
-		@SuppressWarnings("unused")
-		private Object name;
-
-		@SuppressWarnings("unused")
-		private Object value;
-
-	}
-
 	public void runBuild(final HudsonModelJob job, final Map<String, String> parameters, final IOperationMonitor monitor)
 			throws HudsonException {
 		new HudsonOperation<Object>(client) {
 			@Override
-			public Object execute() throws IOException, HudsonException {
-				CommonPostMethod method = (CommonPostMethod) createPostMethod(getJobUrl(job) + "/build");
-				method.setFollowRedirects(false);
-				method.setDoAuthentication(true);
+			public Object execute() throws IOException, HudsonException, JAXBException {
+				HttpPost request = createPostRequest(getJobUrl(job) + "/build");
 				if (parameters != null) {
-					Parameters params = new Parameters();
-					params.parameter = new NameValue[parameters.size()];
-
-					int i = 0;
+					HudsonRunBuildForm form = new HudsonRunBuildForm();
 					for (Entry<String, String> entry : parameters.entrySet()) {
-						method.addParameter(new NameValuePair("name", entry.getKey()));
-						String value = entry.getValue();
-						if (value != null) {
-							method.addParameter(new NameValuePair("value", value));
-						}
-
-						NameValue param = new NameValue();
-						param.name = entry.getKey();
-						param.value = entry.getValue();
-						params.parameter[i++] = param;
+						form.add(entry.getKey(), entry.getValue());
 					}
-					method.addParameter(new NameValuePair("json", new Gson().toJson(params)));
-					method.addParameter(new NameValuePair("Submit", "Build"));
+					request.setEntity(form.createEntity());
 				}
 
-				try {
-					execute(method, monitor);
-					checkResponse(method, 302);
-					return null;
-				} finally {
-					method.releaseConnection(monitor);
-				}
+				CommonHttpResponse response = execute(request, monitor);
+				return processAndRelease(response, monitor);
 			}
+
+			@Override
+			protected void doValidate(CommonHttpResponse response, IOperationMonitor monitor) throws IOException,
+					HudsonException {
+				validate(response, HttpStatus.SC_MOVED_TEMPORARILY, monitor);
+			};
 		}.run();
 	}
 
@@ -433,25 +400,54 @@ public class RestfulHudsonClient {
 	}
 
 	public HudsonServerInfo validate(final IOperationMonitor monitor) throws HudsonException {
-		return new HudsonOperation<HudsonServerInfo>(client) {
+		info = new HudsonOperation<HudsonServerInfo>(client) {
 			@Override
-			public HudsonServerInfo execute() throws IOException, HudsonException {
-				CommonHttpMethod method = createHeadMethod(client.getLocation().getUrl());
-				try {
-					execute(method, monitor);
-					checkResponse(method);
-					Header header = method.getResponseHeader("X-Hudson"); //$NON-NLS-1$
+			public HudsonServerInfo execute() throws IOException, HudsonException, JAXBException {
+				HttpRequestBase request = createHeadRequest(client.getLocation().getUrl());
+				CommonHttpResponse response = execute(request, monitor);
+				return processAndRelease(response, monitor);
+			}
+
+			@Override
+			protected HudsonServerInfo doProcess(CommonHttpResponse response, IOperationMonitor monitor)
+					throws IOException, HudsonException, JAXBException {
+				Header header = response.getResponse().getFirstHeader("X-Jenkins"); //$NON-NLS-1$
+				Type type;
+				if (header == null) {
+					type = Type.HUDSON;
+					header = response.getResponse().getFirstHeader("X-Hudson"); //$NON-NLS-1$
 					if (header == null) {
-						throw new HudsonException(NLS.bind("{0} does not appear to be a Hudson instance",
+						throw new HudsonException(NLS.bind("{0} does not appear to be a Hudson or Jenkins instance",
 								client.getLocation().getUrl()));
 					}
-					HudsonServerInfo info = new HudsonServerInfo(header.getValue());
-					return info;
-				} finally {
-					method.releaseConnection(monitor);
+				} else {
+					type = Type.JENKINS;
 				}
+				HudsonServerInfo info = new HudsonServerInfo(type, header.getValue());
+				return info;
 			}
 		}.run();
+		return info;
+	}
+
+	public RepositoryLocation getLocation() {
+		return client.getLocation();
+	}
+
+	public HudsonServerInfo getInfo() {
+		return info;
+	}
+
+	public HudsonServerInfo getInfo(final IOperationMonitor monitor) throws HudsonException {
+		HudsonServerInfo info = this.info;
+		if (info != null) {
+			return info;
+		}
+		return validate(monitor);
+	}
+
+	public void reset() {
+		client.getHttpClient().getCookieStore().clear();
 	}
 
 }
\ No newline at end of file
