@@ -13,8 +13,10 @@ package org.eclipse.mylyn.commons.core;
 
 import java.io.IOException;
 import java.io.StringReader;
+import java.text.ParseException;
 
-import org.eclipse.mylyn.internal.provisional.commons.core.Html2TextReader;
+import org.eclipse.mylyn.commons.core.HtmlStreamTokenizer.Token;
+import org.eclipse.mylyn.internal.commons.core.Html2TextReader;
 
 /**
  * @author Steffen Pingel
@@ -41,4 +43,22 @@ public class HtmlUtil {
 		return sb.toString();
 	}
 
+	/**
+	 * @since 3.7
+	 */
+	public static String getTextContent(HtmlStreamTokenizer tokenizer) throws IOException, ParseException {
+		StringBuilder sb = new StringBuilder();
+		for (Token token = tokenizer.nextToken(); token.getType() != Token.EOF; token = tokenizer.nextToken()) {
+			if (token.getType() == Token.TEXT) {
+				sb.append(token.toString().trim());
+				sb.append(" "); //$NON-NLS-1$
+			} else if (token.getType() == Token.COMMENT) {
+				// ignore
+			} else {
+				break;
+			}
+		}
+		return sb.toString().trim();
+	}
+
 }
