@@ -14,10 +14,17 @@ package org.eclipse.mylyn.commons.tests;
 import junit.framework.Test;
 import junit.framework.TestSuite;
 
+import org.eclipse.mylyn.commons.tests.core.AuthenticatedProxyTest;
+import org.eclipse.mylyn.commons.tests.core.CommonListenerListTest;
+import org.eclipse.mylyn.commons.tests.core.CoreUtilTest;
+import org.eclipse.mylyn.commons.tests.core.ExtensionPointReaderTest;
+import org.eclipse.mylyn.commons.tests.core.storage.CommonStoreTest;
+import org.eclipse.mylyn.commons.tests.net.NetUtilTest;
 import org.eclipse.mylyn.commons.tests.net.SslProtocolSocketFactoryTest;
 import org.eclipse.mylyn.commons.tests.net.TimeoutInputStreamTest;
 import org.eclipse.mylyn.commons.tests.net.WebUtilTest;
-import org.eclipse.mylyn.commons.tests.ui.CommonUiUtilTest;
+import org.eclipse.mylyn.commons.tests.operations.OperationUtilTest;
+import org.eclipse.mylyn.commons.tests.workbench.browser.BrowserUtilTest;
 
 /**
  * @author Mik Kersten
@@ -25,11 +32,18 @@ import org.eclipse.mylyn.commons.tests.ui.CommonUiUtilTest;
 public class AllCommonsTests {
 
 	public static Test suite() {
-		TestSuite suite = new TestSuite("Test for org.eclipse.mylyn.commons.tests");
+		TestSuite suite = new TestSuite(AllCommonsTests.class.getName());
+		suite.addTestSuite(TimeoutInputStreamTest.class);
+		suite.addTestSuite(CoreUtilTest.class);
+		suite.addTestSuite(AuthenticatedProxyTest.class);
+		suite.addTestSuite(OperationUtilTest.class);
+		suite.addTestSuite(NetUtilTest.class);
 		suite.addTestSuite(SslProtocolSocketFactoryTest.class);
 		suite.addTestSuite(WebUtilTest.class);
-		suite.addTestSuite(CommonUiUtilTest.class);
-		suite.addTestSuite(TimeoutInputStreamTest.class);
+		suite.addTestSuite(BrowserUtilTest.class);
+		suite.addTestSuite(ExtensionPointReaderTest.class);
+		suite.addTestSuite(CommonListenerListTest.class);
+		suite.addTestSuite(CommonStoreTest.class);
 		return suite;
 	}
 
