@@ -40,6 +40,7 @@ import org.eclipse.mylyn.commons.net.AuthenticationType;
 import org.eclipse.mylyn.commons.net.IProxyProvider;
 import org.eclipse.mylyn.commons.net.WebLocation;
 import org.eclipse.mylyn.commons.net.WebUtil;
+import org.eclipse.mylyn.commons.sdk.util.CommonTestUtil;
 import org.eclipse.mylyn.commons.tests.support.TestProxy;
 import org.eclipse.mylyn.commons.tests.support.TestProxy.Message;
 import org.eclipse.mylyn.internal.commons.net.AuthenticatedProxy;
@@ -233,6 +234,13 @@ public class WebUtilTest extends TestCase {
 	}
 
 	public void testReadTimeout() throws Exception {
+		// wait 5 seconds for thread pool to be idle
+		for (int i = 0; i < 10; i++) {
+			if (((ThreadPoolExecutor) CommonsNetPlugin.getExecutorService()).getActiveCount() == 0) {
+				break;
+			}
+			Thread.sleep(500);
+		}
 		assertEquals(0, ((ThreadPoolExecutor) CommonsNetPlugin.getExecutorService()).getActiveCount());
 
 		String url = "http://" + proxyAddress.getHostName() + ":" + proxyAddress.getPort() + "/";
@@ -517,13 +525,16 @@ public class WebUtilTest extends TestCase {
 	}
 
 	public void testLocationConnectSslClientCert() throws Exception {
-		String url = "https://mylyn.eclipse.org/secure/";
-		AbstractWebLocation location = new WebLocation(url, null, null, null);
+		if (CommonTestUtil.isCertificateAuthBroken()) {
+			return; // skip test 
+		}
+
+		String url = "https://mylyn.org/secure/";
+		AbstractWebLocation location = new WebLocation(url);
 		HostConfiguration hostConfiguration = WebUtil.createHostConfiguration(client, location, null);
 
 		if (!((PollingSslProtocolSocketFactory) hostConfiguration.getProtocol().getSocketFactory()).hasKeyManager()) {
-			// skip test if keystore property is not set
-			return;
+			return; // skip test if keystore property is not set
 		}
 
 		GetMethod method = new GetMethod(WebUtil.getRequestPath(url));
