@@ -14,6 +14,7 @@ package org.eclipse.mylyn.discovery.tests;
 import junit.framework.Test;
 import junit.framework.TestSuite;
 
+import org.eclipse.mylyn.commons.sdk.util.TestConfiguration;
 import org.eclipse.mylyn.discovery.tests.core.BundleDiscoveryStrategyTest;
 import org.eclipse.mylyn.discovery.tests.core.ConnectorDiscoveryRemoteTest;
 import org.eclipse.mylyn.discovery.tests.core.ConnectorDiscoveryTest;
@@ -26,12 +27,18 @@ import org.eclipse.mylyn.discovery.tests.core.RemoteBundleDiscoveryStrategyTest;
 public class AllDiscoveryTests {
 
 	public static Test suite() {
-		TestSuite suite = new TestSuite("Tests for org.eclipse.mylyn.discovery");
+		return suite(TestConfiguration.getDefault());
+	}
+
+	public static Test suite(TestConfiguration configuration) {
+		TestSuite suite = new TestSuite(AllDiscoveryTests.class.getName());
 		suite.addTestSuite(ConnectorDiscoveryTest.class);
 		suite.addTestSuite(DirectoryParserTest.class);
 		suite.addTestSuite(BundleDiscoveryStrategyTest.class);
-		suite.addTestSuite(RemoteBundleDiscoveryStrategyTest.class);
-		suite.addTestSuite(ConnectorDiscoveryRemoteTest.class);
+		if (!configuration.isLocalOnly()) {
+			suite.addTestSuite(RemoteBundleDiscoveryStrategyTest.class);
+			suite.addTestSuite(ConnectorDiscoveryRemoteTest.class);
+		}
 		return suite;
 	}
 
