@@ -25,6 +25,7 @@ import java.util.Map;
 import java.util.Set;
 import java.util.regex.Pattern;
 
+import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.IStatus;
@@ -46,6 +47,11 @@ import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.jface.viewers.ViewerFilter;
 import org.eclipse.jface.window.IShellProvider;
+import org.eclipse.mylyn.commons.ui.CommonImages;
+import org.eclipse.mylyn.commons.ui.GradientCanvas;
+import org.eclipse.mylyn.commons.ui.SelectionProviderAdapter;
+import org.eclipse.mylyn.commons.ui.compatibility.CommonThemes;
+import org.eclipse.mylyn.commons.workbench.browser.BrowserUtil;
 import org.eclipse.mylyn.internal.discovery.core.model.AbstractDiscoverySource;
 import org.eclipse.mylyn.internal.discovery.core.model.BundleDiscoveryStrategy;
 import org.eclipse.mylyn.internal.discovery.core.model.ConnectorDescriptor;
@@ -60,11 +66,6 @@ import org.eclipse.mylyn.internal.discovery.core.util.DiscoveryCategoryComparato
 import org.eclipse.mylyn.internal.discovery.core.util.DiscoveryConnectorComparator;
 import org.eclipse.mylyn.internal.discovery.ui.DiscoveryImages;
 import org.eclipse.mylyn.internal.discovery.ui.DiscoveryUi;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonImages;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonThemes;
-import org.eclipse.mylyn.internal.provisional.commons.ui.GradientCanvas;
-import org.eclipse.mylyn.internal.provisional.commons.ui.SelectionProviderAdapter;
-import org.eclipse.mylyn.internal.provisional.commons.ui.WorkbenchUtil;
 import org.eclipse.osgi.util.NLS;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.accessibility.ACC;
@@ -237,7 +238,7 @@ public class DiscoveryViewer {
 					providerLabel.addSelectionListener(new SelectionAdapter() {
 						@Override
 						public void widgetSelected(SelectionEvent e) {
-							WorkbenchUtil.openUrl(connector.getCertification().getUrl(),
+							BrowserUtil.openUrl(connector.getCertification().getUrl(),
 									IWorkbenchBrowserSupport.AS_EXTERNAL);
 						}
 					});
@@ -1103,6 +1104,10 @@ public class DiscoveryViewer {
 		}
 	}
 
+	public String getFilterText() {
+		return filterText.getText();
+	}
+
 	public List<ConnectorDescriptor> getInstallableConnectors() {
 		return installableConnectors;
 	}
@@ -1407,6 +1412,12 @@ public class DiscoveryViewer {
 		this.environment = environment;
 	}
 
+	public void setFilterText(String text) {
+		Assert.isNotNull(text);
+		filterText.setText(text);
+		filterTextChanged();
+	}
+
 	public void setSelection(IStructuredSelection selection) {
 		Set<ConnectorDescriptor> selected = new HashSet<ConnectorDescriptor>();
 		for (Object descriptor : selection.toArray()) {
