@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2010 David Green and others.
+ * Copyright (c) 2007, 2011 David Green and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,6 +12,7 @@ package org.eclipse.mylyn.wikitext.core.parser.markup;
 
 import java.io.IOException;
 import java.io.StringReader;
+import java.io.Writer;
 import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Collections;
@@ -164,13 +165,21 @@ public abstract class MarkupLanguage implements Cloneable {
 							}
 						}
 						if (currentBlock == null) {
-							currentBlock = startBlock(line, lineOffset);
+							if (nestedBlocks != null && !nestedBlocks.isEmpty()) {
+								Block nestedParent = nestedBlocks.peek();
+								if (nestedParent.canResume(line, lineOffset)) {
+									currentBlock = nestedParent;
+								}
+							}
 							if (currentBlock == null) {
-								break;
+								currentBlock = startBlock(line, lineOffset);
+								if (currentBlock == null) {
+									break;
+								}
+								currentBlock.setMarkupLanguage(this);
+								currentBlock.setState(state);
+								currentBlock.setParser(parser);
 							}
-							currentBlock.setMarkupLanguage(this);
-							currentBlock.setState(state);
-							currentBlock.setParser(parser);
 						}
 						lineOffset = currentBlock.processLineContent(line, lineOffset);
 						if (currentBlock.isClosed()) {
@@ -679,4 +688,18 @@ public abstract class MarkupLanguage implements Cloneable {
 	public void setEnableMacros(boolean enableMacros) {
 		this.enableMacros = enableMacros;
 	}
+
+	/**
+	 * Create a document builder suitable for emitting content in this markup language
+	 * 
+	 * @param out
+	 *            the target to which content is written
+	 * @return a document builder
+	 * @throws UnsupportedOperationException
+	 *             if the markup language has no corresponding document builder
+	 * @since 1.6
+	 */
+	public DocumentBuilder createDocumentBuilder(Writer out) {
+		throw new UnsupportedOperationException();
+	}
 }
