@@ -341,7 +341,6 @@ public class WikiToDocTask extends MarkupTask {
 		return computeTocRelativeFile(item, path);
 	}
 
-	@SuppressWarnings("restriction")
 	private String computeTocRelativeFile(OutlineItem item, Path path) {
 		String name = ((SplitOutlineItem) item).getSplitTarget();
 		File pathDestDir = computeDestDir(path);
@@ -822,7 +821,7 @@ public class WikiToDocTask extends MarkupTask {
 					String relativeDir = destDir.getAbsolutePath().substring(dest.getAbsolutePath().length());
 					//URL path separator is always forward slash
 					if (File.separatorChar == '\\') {
-						relativeDir.replace('\\', '/');
+						relativeDir = relativeDir.replace('\\', '/');
 					}
 					if (relativeDir.startsWith("/")) { //$NON-NLS-1$
 						relativeDir = relativeDir.substring(1);
