@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2011 David Green and others.
+ * Copyright (c) 2007, 2012 David Green and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -41,7 +41,7 @@ public class TextileLanguageTest extends TestCase {
 
 	private MarkupParser parser;
 
-	private TextileLanguage markupLanaguage;
+	private TextileLanguage markupLanguage;
 
 	@Override
 	public void setUp() throws Exception {
@@ -51,12 +51,12 @@ public class TextileLanguageTest extends TestCase {
 
 	private void initParser() throws IOException {
 		parser = new MarkupParser();
-		markupLanaguage = new TextileLanguage();
-		parser.setMarkupLanguage(markupLanaguage);
+		markupLanguage = new TextileLanguage();
+		parser.setMarkupLanguage(markupLanguage);
 	}
 
 	public void testIsDetectingRawHyperlinks() {
-		assertFalse(markupLanaguage.isDetectingRawHyperlinks());
+		assertFalse(markupLanguage.isDetectingRawHyperlinks());
 	}
 
 	public void testSimpleHeaders() {
@@ -234,6 +234,30 @@ public class TextileLanguageTest extends TestCase {
 		assertTrue(html.contains("A&amp;BC"));
 	}
 
+	public void testHtmlEntityEncoding2() {
+		String html = parser.parseToHtml("Some A&BC Thing; two");
+		TestUtil.println("HTML: \n" + html);
+		assertTrue(html.contains("<p>Some A&amp;BC Thing; two</p>"));
+	}
+
+	public void testHtmlEntityEncoding3() {
+		String html = parser.parseToHtml("Some A&BCThing; two");
+		TestUtil.println("HTML: \n" + html);
+		assertTrue(html.contains("<p>Some A&BCThing; two</p>"));
+	}
+
+	public void testHtmlEntityEncoding4() {
+		String html = parser.parseToHtml("Some A&#60; two");
+		TestUtil.println("HTML: \n" + html);
+		assertTrue(html.contains("<p>Some A&#60; two</p>"));
+	}
+
+	public void testHtmlEntityEncoding5() {
+		String html = parser.parseToHtml("Some A&#x27; two");
+		TestUtil.println("HTML: \n" + html);
+		assertTrue(html.contains("<p>Some A&#x27; two</p>"));
+	}
+
 	public void testParagraphs() throws IOException {
 		String html = parser.parseToHtml("first para\nnew line\n\nsecond para\n\n\n\n");
 		TestUtil.println(html);
@@ -430,7 +454,7 @@ public class TextileLanguageTest extends TestCase {
 	}
 
 	public void testFootnoteRefNoFootnote() throws IOException {
-		markupLanaguage.setPreprocessFootnotes(true);
+		markupLanguage.setPreprocessFootnotes(true);
 		String html = parser.parseToHtml("See foo[1].\n\nNo such footnote!");
 
 		TestUtil.println("HTML: \n" + html);
@@ -530,7 +554,7 @@ public class TextileLanguageTest extends TestCase {
 		String html = parser.parseToHtml("table.\n|^a|<row with|>four|<>columns|");
 
 		TestUtil.println("HTML: \n" + html);
-		assertTrue(html.contains("<table><tr><td style=\"text-align: top;\">a</td><td style=\"text-align: left;\">row with</td><td style=\"text-align: right;\">four</td><td style=\"text-align: center;\">columns</td></tr></table>"));
+		assertTrue(html.contains("<table><tr><td style=\"vertical-align: top;\">a</td><td style=\"text-align: left;\">row with</td><td style=\"text-align: right;\">four</td><td style=\"text-align: center;\">columns</td></tr></table>"));
 	}
 
 	public void testTableCellColspan() throws IOException {
@@ -684,6 +708,14 @@ public class TextileLanguageTest extends TestCase {
 		}
 	}
 
+	public void testPhraseModifierDeletedWithHyphens_bug321538() {
+		String html = parser.parseToHtml("as I said, -hello oh-so-cruel world- again.\n\nThis works: -hell world-\n\nThis doesn't: -hello oh-so-cruel world-");
+		TestUtil.println("HTML: \n" + html);
+		assertTrue(html.contains("<p>as I said, <del>hello oh-so-cruel world</del> again.</p>"));
+		assertTrue(html.contains("<p>This works: <del>hell world</del></p>"));
+		assertTrue(html.contains("<p>This doesn&#8217;t: <del>hello oh-so-cruel world</del></p>"));
+	}
+
 	public void testImage() throws IOException {
 		String html = parser.parseToHtml("Here comes an !imageUrl! with more text");
 
@@ -879,6 +911,28 @@ public class TextileLanguageTest extends TestCase {
 		assertTrue(html.contains("<body><p>{toc} Generates a table of contents.  Eg: {toc} or {toc:style=disc|maxLevel=3}</p></body>"));
 	}
 
+	public void testEscaping_NoTextile() throws IOException {
+		String html = parser.parseToHtml("notextile. foo <b>bar</b>\n<i>baz</i>\n\ntextile *here*");
+
+		TestUtil.println(html);
+
+		assertTrue(Pattern.compile("<body>foo <b>bar</b>\\s+<i>baz</i>\\s+<p>textile <strong>here</strong></p></body>")
+				.matcher(html)
+				.find());
+	}
+
+	public void testEscaping_NoTextile_Extended() throws IOException {
+		String html = parser.parseToHtml("notextile.. foo <b>bar</b>\n<i>baz</i>\n\nnotextile *here*\n\np. textile *here*");
+
+		TestUtil.println(html);
+
+		assertTrue(Pattern.compile(
+				"<body>foo <b>bar</b>\\s+<i>baz</i>" + "\\s*notextile \\*here\\*"
+						+ "\\s+<p>textile <strong>here</strong></p></body>")
+				.matcher(html)
+				.find());
+	}
+
 	public void testReplacements() throws IOException {
 		String html = parser.parseToHtml("some text with copyright(c), trademark(tm) and registered(r)");
 
@@ -1433,19 +1487,48 @@ public class TextileLanguageTest extends TestCase {
 
 	public void testMarkupContainingCDATA() {
 		// bug 302291 text containing CDATA produces invalid HTML
-		String html = parser.parseToHtml("pre. <![CDATA[123 456]]>");
-		TestUtil.println(html);
-		assertTrue(html.contains("&lt;![CDATA[123 456]]&gt;"));
+
+		for (String blockType : new String[] { "pre", "bc" }) {
+
+			String html = parser.parseToHtml(blockType + ". <![CDATA[123 456]]>");
+			TestUtil.println(html);
+			assertTrue(html.contains("&lt;![CDATA[123 456]]&gt;"));
+
+		}
 	}
 
 	public void testEntityReferences() {
-		String[] entities = new String[] { "copy", "amp", "foobar" };
+		String[] entities = new String[] { "copy", "amp", "foobar", "#28", "x3C", "x3E" };
 		for (String entity : entities) {
 			String markup = "text &" + entity + ";";
 			String html = parser.parseToHtml(markup);
 			TestUtil.println(html);
 			assertTrue(html.contains("&" + entity + ";"));
 
+			markup = "&" + entity + ";";
+			html = parser.parseToHtml(markup);
+			TestUtil.println(html);
+			assertTrue(html.contains("&" + entity + ";"));
+
+			markup = "&" + entity + "; text";
+			html = parser.parseToHtml(markup);
+			TestUtil.println(html);
+			assertTrue(html.contains("&" + entity + ";"));
+		}
+	}
+
+	public void testEntityReferences_NegativeMatch() {
+		String[] entities = new String[] { "copy", "amp", "foobar", "#28", "x3C", "x3E" };
+		for (String entity : entities) {
+			String markup = "text &" + entity + " ;";
+			String html = parser.parseToHtml(markup);
+			TestUtil.println(html);
+			assertTrue(html.contains("&amp;" + entity + " ;"));
+
+			markup = "text & " + entity + ";";
+			html = parser.parseToHtml(markup);
+			TestUtil.println(html);
+			assertTrue(html.contains("&amp; " + entity + ";"));
 		}
 	}
 }
