@@ -131,6 +131,8 @@ public class BugzillaRepositoryConnector extends AbstractRepositoryConnector {
 		enSetting.addLanguageAttribute("submitted", "Submitted"); //$NON-NLS-1$ //$NON-NLS-2$
 		enSetting.addLanguageAttribute("submitted", "posted"); //$NON-NLS-1$ //$NON-NLS-2$
 		enSetting.addLanguageAttribute("suspicious_action", "Suspicious action"); //$NON-NLS-1$ //$NON-NLS-2$
+		enSetting.addLanguageAttribute("error_confirm_match", "confirm match"); //$NON-NLS-1$//$NON-NLS-2$
+		enSetting.addLanguageAttribute("error_match_failed", "match failed"); //$NON-NLS-1$ //$NON-NLS-2$
 		languages.add(enSetting);
 
 		java2buzillaPlatformMap.put("x86", "PC"); // can be PC or Macintosh! //$NON-NLS-1$ //$NON-NLS-2$
@@ -666,19 +668,14 @@ public class BugzillaRepositoryConnector extends AbstractRepositoryConnector {
 			@Override
 			public PriorityLevel getPriorityLevel() {
 				RepositoryConfiguration repositoryConfiguration = BugzillaRepositoryConnector.this.getRepositoryConfiguration(taskData.getRepositoryUrl());
-				BugzillaVersion bugzillaVersion;
-				if (repositoryConfiguration != null) {
-					bugzillaVersion = repositoryConfiguration.getInstallVersion();
-				} else {
-					bugzillaVersion = BugzillaVersion.MIN_VERSION;
+				String priority = getPriority();
+				if (repositoryConfiguration == null) {
+					// When we did not have the configuration we only can use the standard Priorities
+					// Did not know how the configuration can be null here
+					return getTaskPriority(priority);
 				}
-				if (bugzillaVersion.compareTo(BugzillaVersion.BUGZILLA_3_6) >= 0) {
-					BugzillaPriorityLevel bugzillaPriorityLevel = BugzillaPriorityLevel.fromPriority(getPriority());
-					if (bugzillaPriorityLevel != null) {
-						return bugzillaPriorityLevel.toPriorityLevel();
-					}
-				}
-				return super.getPriorityLevel();
+				List<String> priorities = repositoryConfiguration.getPriorities();
+				return BugzillaRepositoryConnector.getTaskPriority(priority, priorities);
 			}
 		};
 	}
@@ -1100,4 +1097,30 @@ public class BugzillaRepositoryConnector extends AbstractRepositoryConnector {
 		}
 		return history;
 	}
+
+	public static PriorityLevel getTaskPriority(String bugzillaPriority) {
+		if (bugzillaPriority != null) {
+			BugzillaPriorityLevel priority = BugzillaPriorityLevel.fromPriority(bugzillaPriority);
+			if (priority != null) {
+				return priority.toPriorityLevel();
+			}
+		}
+		return PriorityLevel.fromString(bugzillaPriority);
+	}
+
+	public static PriorityLevel getTaskPriority(String priority, List<String> priorities) {
+		if (priority != null && priorities != null && priorities.size() > 0) {
+			int size = priorities.size() - 1;
+			int index = 0;
+			for (String priority2test : priorities) {
+				if (priority.equals(priority2test)) {
+					float relativeValue = (float) index / size;
+					int value = (int) (relativeValue * 5) + 1;
+					return PriorityLevel.fromLevel(value);
+				}
+				index++;
+			}
+		}
+		return getTaskPriority(priority);
+	}
 }
