@@ -20,6 +20,7 @@ import java.util.Locale;
 import java.util.Map;
 
 import org.eclipse.mylyn.tasks.core.IRepositoryPerson;
+import org.eclipse.mylyn.tasks.core.TaskRepository;
 import org.eclipse.mylyn.tasks.core.data.TaskAttribute;
 import org.eclipse.mylyn.tasks.core.data.TaskAttributeMapper;
 import org.eclipse.mylyn.tasks.core.data.TaskCommentMapper;
@@ -79,15 +80,25 @@ public class SaxMultiBugReportContentHandler extends DefaultHandler {
 
 	private final BugzillaRepositoryConnector connector;
 
+	private boolean useIsPrivate;
+
+	private final TaskAttributeMapper mapper;
+
 	private final SimpleDateFormat simpleFormatter = new SimpleDateFormat("yyyy-MM-dd HH:mm"); //$NON-NLS-1$
 
+	private final SimpleDateFormat simpleFormatter_deltaTS = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss"); //$NON-NLS-1$
+
 	public SaxMultiBugReportContentHandler(TaskAttributeMapper mapper, TaskDataCollector collector,
 			Map<String, TaskData> taskDataMap, List<BugzillaCustomField> customFields,
 			BugzillaRepositoryConnector connector) {
+		this.mapper = mapper;
 		this.taskDataMap = taskDataMap;
 		this.customFields = customFields;
 		this.collector = collector;
 		this.connector = connector;
+		TaskRepository taskRepository = mapper.getTaskRepository();
+		String useParam = taskRepository.getProperty(IBugzillaConstants.BUGZILLA_INSIDER_GROUP);
+		useIsPrivate = (useParam == null || (useParam != null && useParam.equals("true"))); //$NON-NLS-1$
 	}
 
 	public boolean errorOccurred() {
@@ -141,7 +152,7 @@ public class SaxMultiBugReportContentHandler extends DefaultHandler {
 			token = null;
 			break;
 		case LONG_DESC:
-			String is_private = attributes.getValue("isprivate");
+			String is_private = attributes.getValue("isprivate"); //$NON-NLS-1$
 			taskComment = new TaskComment(is_private);
 			break;
 		case WHO:
@@ -313,6 +324,8 @@ public class SaxMultiBugReportContentHandler extends DefaultHandler {
 
 			if (exporter != null) {
 				createAttrribute(exporter, BugzillaAttribute.EXPORTER_NAME);
+			} else {
+				createAttrribute("", BugzillaAttribute.EXPORTER_NAME); //$NON-NLS-1$
 			}
 
 			break;
@@ -382,6 +395,23 @@ public class SaxMultiBugReportContentHandler extends DefaultHandler {
 				attachment.setContentType(parsedText);
 			}
 			break;
+		case DELTA_TS:
+			if (attachment != null) {
+				try {
+					if (parsedText != null) {
+						try {
+							attachment.setDeltaDate(simpleFormatter_deltaTS.parse(parsedText));
+						} catch (ParseException e) {
+						}
+					}
+				} catch (NumberFormatException e) {
+					// ignore
+				}
+			} else {
+				createAttrribute(parsedText, tag);
+			}
+			break;
+
 		case SIZE:
 			if (attachment != null) {
 				try {
@@ -495,7 +525,6 @@ public class SaxMultiBugReportContentHandler extends DefaultHandler {
 				IRepositoryPerson author = repositoryTaskData.getAttributeMapper()
 						.getTaskRepository()
 						.createPerson(parsedText);
-				author.setName(parsedText);
 				attachment.setAuthor(author);
 			}
 			break;
@@ -614,14 +643,14 @@ public class SaxMultiBugReportContentHandler extends DefaultHandler {
 		int longDescsSize = longDescs.size() - 1;
 		commentNum = 1;
 		if (longDescsSize == 0) {
-			addDescription(longDescs.get(0).commentText);
+			addDescription(longDescs.get(0));
 		} else if (longDescsSize == 1) {
 			if (longDescs.get(0).createdTimeStamp.compareTo(longDescs.get(1).createdTimeStamp) <= 0) {
 				// if created_0 is equal to created_1 we assume that longDescs at index 0 is the description.
-				addDescription(longDescs.get(0).commentText);
+				addDescription(longDescs.get(0));
 				addComment(longDescs.get(1));
 			} else {
-				addDescription(longDescs.get(1).commentText);
+				addDescription(longDescs.get(1));
 				addComment(longDescs.get(0));
 			}
 		} else if (longDescsSize > 1) {
@@ -630,7 +659,7 @@ public class SaxMultiBugReportContentHandler extends DefaultHandler {
 			String created_n = longDescs.get(longDescsSize).createdTimeStamp;
 			if (created_0.compareTo(created_1) <= 0 && created_0.compareTo(created_n) < 0) {
 				// if created_0 is equal to created_1 we assume that longDescs at index 0 is the description.
-				addDescription(longDescs.get(0).commentText);
+				addDescription(longDescs.get(0));
 
 				if (created_1.compareTo(created_n) < 0) {
 					for (int i = 1; i <= longDescsSize; i++) {
@@ -642,7 +671,7 @@ public class SaxMultiBugReportContentHandler extends DefaultHandler {
 					}
 				}
 			} else {
-				addDescription(longDescs.get(longDescsSize).commentText);
+				addDescription(longDescs.get(longDescsSize));
 				if (created_0.compareTo(created_1) < 0) {
 					for (int i = 0; i < longDescsSize; i++) {
 						addComment(longDescs.get(i));
@@ -656,24 +685,48 @@ public class SaxMultiBugReportContentHandler extends DefaultHandler {
 		}
 	}
 
-	private void addDescription(String commentText) {
+	private void addDescription(TaskComment comment) {
 		TaskAttribute attrDescription = BugzillaTaskDataHandler.createAttribute(repositoryTaskData,
 				BugzillaAttribute.LONG_DESC);
-		attrDescription.setValue(commentText);
+		TaskAttribute idAttribute = attrDescription.createAttribute(IBugzillaConstants.BUGZILLA_DESCRIPTION_ID);
+		TaskAttribute isprivateAttribute = attrDescription.createAttribute(IBugzillaConstants.BUGZILLA_DESCRIPTION_IS_PRIVATE);
+		attrDescription.setValue(comment.commentText);
+		idAttribute.setValue(Integer.toString(comment.id));
+		if (comment.isPrivate != null) {
+			isprivateAttribute.setValue(comment.isPrivate);
+		}
+		if (!useIsPrivate) {
+			if ("1".equals(comment.isPrivate)) { //$NON-NLS-1$
+				TaskRepository taskRepository = mapper.getTaskRepository();
+				taskRepository.setProperty(IBugzillaConstants.BUGZILLA_INSIDER_GROUP, "true"); //$NON-NLS-1$
+				useIsPrivate = true;
+			}
+		}
 	}
 
 	private void addComment(TaskComment comment) {
 		TaskAttribute attribute = repositoryTaskData.getRoot().createAttribute(
 				TaskAttribute.PREFIX_COMMENT + commentNum);
 		TaskCommentMapper taskComment = TaskCommentMapper.createFrom(attribute);
-		taskComment.setCommentId(commentNum + ""); //$NON-NLS-1$
+		taskComment.setCommentId(comment.id + ""); //$NON-NLS-1$
 		taskComment.setNumber(commentNum);
 		IRepositoryPerson author = repositoryTaskData.getAttributeMapper()
 				.getTaskRepository()
 				.createPerson(comment.author);
 		author.setName(comment.authorName);
 		taskComment.setAuthor(author);
-		taskComment.setIsPrivate("1".equals(comment.isPrivate)); //$NON-NLS-1$
+		if (useIsPrivate) {
+			taskComment.setIsPrivate("1".equals(comment.isPrivate)); //$NON-NLS-1$
+		} else {
+			if ("1".equals(comment.isPrivate)) { //$NON-NLS-1$
+				TaskRepository taskRepository = mapper.getTaskRepository();
+				taskRepository.setProperty(IBugzillaConstants.BUGZILLA_INSIDER_GROUP, "true"); //$NON-NLS-1$
+				useIsPrivate = true;
+				taskComment.setIsPrivate("1".equals(comment.isPrivate)); //$NON-NLS-1$
+			} else {
+				taskComment.setIsPrivate(null);
+			}
+		}
 		TaskAttribute attrTimestamp = attribute.createAttribute(BugzillaAttribute.BUG_WHEN.getKey());
 		attrTimestamp.setValue(comment.createdTimeStamp);
 		taskComment.setCreationDate(repositoryTaskData.getAttributeMapper().getDateValue(attrTimestamp));
@@ -690,15 +743,7 @@ public class SaxMultiBugReportContentHandler extends DefaultHandler {
 			workTime.setValue(comment.timeWorked);
 		}
 
-		if (comment.id != 0) {
-			TaskAttribute commentID = BugzillaTaskDataHandler.createAttribute(attribute, BugzillaAttribute.COMMENTID);
-			commentID.setValue(Integer.toString(comment.id));
-			int i = 9;
-			i++;
-		}
-
 		parseAttachment(taskComment);
-
 	}
 
 	/** determines attachment id from comment */
