@@ -12,10 +12,13 @@
 package org.eclipse.mylyn.bugzilla.tests;
 
 import java.io.File;
+import java.io.IOException;
 import java.text.DateFormat;
 import java.text.SimpleDateFormat;
+import java.util.Collections;
 import java.util.Date;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Set;
 
 import org.eclipse.core.runtime.CoreException;
@@ -27,11 +30,12 @@ import org.eclipse.mylyn.internal.bugzilla.core.BugzillaAttribute;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaClient;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaCorePlugin;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaOperation;
+import org.eclipse.mylyn.internal.bugzilla.core.BugzillaStatus;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaTaskDataHandler;
+import org.eclipse.mylyn.internal.bugzilla.core.BugzillaUserMatchResponse;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaVersion;
 import org.eclipse.mylyn.internal.bugzilla.core.IBugzillaConstants;
 import org.eclipse.mylyn.internal.bugzilla.core.RepositoryConfiguration;
-import org.eclipse.mylyn.internal.context.core.ContextCorePlugin;
 import org.eclipse.mylyn.internal.tasks.core.AbstractTask;
 import org.eclipse.mylyn.internal.tasks.core.RepositoryQuery;
 import org.eclipse.mylyn.internal.tasks.core.TaskRepositoryLocation;
@@ -53,7 +57,7 @@ import org.eclipse.mylyn.tasks.core.data.TaskDataModel;
 import org.eclipse.mylyn.tasks.core.data.TaskOperation;
 import org.eclipse.mylyn.tasks.ui.TasksUi;
 import org.eclipse.mylyn.tasks.ui.TasksUiUtil;
-import org.eclipse.mylyn.tests.util.TestUtil.PrivilegeLevel;
+import org.eclipse.mylyn.commons.sdk.util.CommonTestUtil.PrivilegeLevel;
 
 /**
  * @author Rob Elves
@@ -342,7 +346,8 @@ public class BugzillaRepositoryConnectorTest extends AbstractBugzillaTest {
 //
 	public void testStdWorkflow() throws Exception {
 		if (BugzillaFixture.current().getBugzillaVersion().compareMajorMinorOnly(BugzillaVersion.BUGZILLA_4_0) < 0) {
-			if (BugzillaFixture.current() != BugzillaFixture.BUGS_3_6_CUSTOM_WF) {
+			if (BugzillaFixture.current() != BugzillaFixture.BUGS_3_6_CUSTOM_WF
+					&& BugzillaFixture.current() != BugzillaFixture.BUGS_3_6_CUSTOM_WF_AND_STATUS) {
 				doStdWorkflow32("3");
 			}
 		} else {
@@ -830,7 +835,7 @@ public class BugzillaRepositoryConnectorTest extends AbstractBugzillaTest {
 		ITask task = generateLocalTaskAndDownload(data.getTaskId());
 		assertNotNull(task);
 		TasksUiPlugin.getTaskActivityManager().activateTask(task);
-		File sourceContextFile = ContextCorePlugin.getContextStore().getFileForContext(task.getHandleIdentifier());
+		File sourceContextFile = TasksUiPlugin.getContextStore().getFileForContext(task);
 		assertEquals(SynchronizationState.SYNCHRONIZED, task.getSynchronizationState());
 		sourceContextFile.createNewFile();
 		sourceContextFile.deleteOnExit();
@@ -1062,6 +1067,11 @@ public class BugzillaRepositoryConnectorTest extends AbstractBugzillaTest {
 			// Until we found the reason we disable this test for the 4.1 bugzilla on mylyn.eclipse.org
 			return;
 		}
+		RepositoryConfiguration repositoryConfiguration = connector.getRepositoryConfiguration(repository.getRepositoryUrl());
+		List<String> priorities = repositoryConfiguration.getPriorities();
+		String priority1 = priorities.get(0);
+		String priority2 = priorities.get(1);
+
 		assertNotNull(data);
 		ITask task4 = generateLocalTaskAndDownload(data.getTaskId());
 		assertNotNull(task4);
@@ -1109,20 +1119,20 @@ public class BugzillaRepositoryConnectorTest extends AbstractBugzillaTest {
 		assertTrue(event.getStaleTasks().contains(task5));
 
 		String priority4 = null;
-		if (task4.getPriority().equals("P1")) {
-			priority4 = "P2";
+		if (task4.getPriority().equals(priority1)) {
+			priority4 = priority2;
 			taskData4.getRoot().getAttribute(BugzillaAttribute.PRIORITY.getKey()).setValue(priority4);
 		} else {
-			priority4 = "P1";
+			priority4 = priority1;
 			taskData4.getRoot().getAttribute(BugzillaAttribute.PRIORITY.getKey()).setValue(priority4);
 		}
 
 		String priority5 = null;
-		if (task5.getPriority().equals("P1")) {
-			priority5 = "P2";
+		if (task5.getPriority().equals(priority1)) {
+			priority5 = priority2;
 			taskData5.getRoot().getAttribute(BugzillaAttribute.PRIORITY.getKey()).setValue(priority5);
 		} else {
-			priority5 = "P1";
+			priority5 = priority1;
 			taskData5.getRoot().getAttribute(BugzillaAttribute.PRIORITY.getKey()).setValue(priority5);
 		}
 		Set<TaskAttribute> changed4 = new HashSet<TaskAttribute>();
@@ -1180,4 +1190,478 @@ public class BugzillaRepositoryConnectorTest extends AbstractBugzillaTest {
 		fail("Should have failed due to an empty password.");
 	}
 
+	public void testErrorMatchFailedToShort() throws Exception {
+		try {
+			doUserMatch("st", null);
+			fail("CoreException expected but not found");
+		} catch (CoreException e) {
+			assertEquals(BugzillaStatus.ERROR_MATCH_FAILED, e.getStatus().getCode());
+			BugzillaStatus status = (BugzillaStatus) e.getStatus();
+			assertNotNull(status);
+			BugzillaUserMatchResponse matchUserResponse = status.getUserMatchResponse();
+			assertNotNull(matchUserResponse);
+			assertNotNull(matchUserResponse.getNewCCProposals());
+			assertNotNull(matchUserResponse.getAssignedToProposals());
+			assertNotNull(matchUserResponse.getQaContactProposals());
+			assertEquals(0, matchUserResponse.getNewCCProposals().size());
+			assertEquals(0, matchUserResponse.getAssignedToProposals().size());
+			assertEquals(0, matchUserResponse.getQaContactProposals().size());
+			assertNotNull(matchUserResponse.getNewCCMsg());
+			assertNull(matchUserResponse.getAssignedToMsg());
+			assertNull(matchUserResponse.getQaContactMsg());
+			if (BugzillaFixture.current().getBugzillaVersion().compareMajorMinorOnly(BugzillaVersion.BUGZILLA_3_6) < 0) {
+				assertTrue(matchUserResponse.getNewCCMsg().equals("st  did not match anything "));
+			} else {
+				assertTrue(matchUserResponse.getNewCCMsg().equals(
+						"st  was too short for substring match (minimum 3 characters) "));
+			}
+		}
+	}
+
+	public void testErrorMatchConfirmMatch() throws Exception {
+		try {
+			doUserMatch("est", null);
+			fail("CoreException expected but not found");
+		} catch (CoreException e) {
+			if (BugzillaFixture.current().getBugzillaVersion().compareMajorMinorOnly(BugzillaVersion.BUGZILLA_3_6) < 0) {
+				assertEquals(BugzillaStatus.ERROR_MATCH_FAILED, e.getStatus().getCode());
+				BugzillaStatus status = (BugzillaStatus) e.getStatus();
+				assertNotNull(status);
+				BugzillaUserMatchResponse matchUserResponse = status.getUserMatchResponse();
+				assertNotNull(matchUserResponse);
+				assertNotNull(matchUserResponse.getNewCCProposals());
+				assertNotNull(matchUserResponse.getAssignedToProposals());
+				assertNotNull(matchUserResponse.getQaContactProposals());
+				assertEquals(Collections.emptyList(), matchUserResponse.getNewCCProposals());
+				assertEquals(Collections.emptyList(), matchUserResponse.getAssignedToProposals());
+				assertEquals(Collections.emptyList(), matchUserResponse.getQaContactProposals());
+				assertNotNull(matchUserResponse.getNewCCMsg());
+				assertNull(matchUserResponse.getAssignedToMsg());
+				assertNull(matchUserResponse.getQaContactMsg());
+				assertTrue(matchUserResponse.getNewCCMsg().equals("est  did not match anything "));
+			} else {
+				assertEquals(BugzillaStatus.ERROR_CONFIRM_MATCH, e.getStatus().getCode());
+				BugzillaStatus status = (BugzillaStatus) e.getStatus();
+				assertNotNull(status);
+				BugzillaUserMatchResponse matchUserResponse = status.getUserMatchResponse();
+				assertNotNull(matchUserResponse);
+				assertNotNull(matchUserResponse.getNewCCProposals());
+				assertNotNull(matchUserResponse.getAssignedToProposals());
+				assertNotNull(matchUserResponse.getQaContactProposals());
+				assertEquals(2, matchUserResponse.getNewCCProposals().size());
+				assertEquals(Collections.emptyList(), matchUserResponse.getAssignedToProposals());
+				assertEquals(Collections.emptyList(), matchUserResponse.getQaContactProposals());
+				assertTrue(matchUserResponse.getNewCCProposals().contains("tests@mylyn.eclipse.org"));
+				assertTrue(matchUserResponse.getNewCCProposals().contains("guest@mylyn.eclipse.org"));
+				assertNull(matchUserResponse.getNewCCMsg());
+				assertNull(matchUserResponse.getAssignedToMsg());
+				assertNull(matchUserResponse.getQaContactMsg());
+			}
+		}
+	}
+
+	public void testErrorMatchConfirmMatch2() throws Exception {
+		try {
+			doUserMatch(null, "est");
+			fail("CoreException expected but not found");
+		} catch (CoreException e) {
+			if (BugzillaFixture.current().getBugzillaVersion().compareMajorMinorOnly(BugzillaVersion.BUGZILLA_3_6) < 0) {
+				assertEquals(BugzillaStatus.ERROR_MATCH_FAILED, e.getStatus().getCode());
+				BugzillaStatus status = (BugzillaStatus) e.getStatus();
+				assertNotNull(status);
+				BugzillaUserMatchResponse matchUserResponse = status.getUserMatchResponse();
+				assertNotNull(matchUserResponse);
+				assertNotNull(matchUserResponse.getNewCCProposals());
+				assertNotNull(matchUserResponse.getAssignedToProposals());
+				assertNotNull(matchUserResponse.getQaContactProposals());
+				assertEquals(Collections.emptyList(), matchUserResponse.getNewCCProposals());
+				assertEquals(Collections.emptyList(), matchUserResponse.getAssignedToProposals());
+				assertEquals(Collections.emptyList(), matchUserResponse.getQaContactProposals());
+				assertNull(matchUserResponse.getNewCCMsg());
+				assertNotNull(matchUserResponse.getAssignedToMsg());
+				assertNull(matchUserResponse.getQaContactMsg());
+				assertTrue(matchUserResponse.getAssignedToMsg().equals("est  did not match anything "));
+			} else {
+				assertEquals(BugzillaStatus.ERROR_CONFIRM_MATCH, e.getStatus().getCode());
+				BugzillaStatus status = (BugzillaStatus) e.getStatus();
+				assertNotNull(status);
+				BugzillaUserMatchResponse matchUserResponse = status.getUserMatchResponse();
+				assertNotNull(matchUserResponse);
+				assertNotNull(matchUserResponse.getNewCCProposals());
+				assertNotNull(matchUserResponse.getAssignedToProposals());
+				assertNotNull(matchUserResponse.getQaContactProposals());
+				assertEquals(Collections.emptyList(), matchUserResponse.getNewCCProposals());
+				assertEquals(2, matchUserResponse.getAssignedToProposals().size());
+				assertEquals(Collections.emptyList(), matchUserResponse.getQaContactProposals());
+				assertTrue(matchUserResponse.getAssignedToProposals().contains("tests@mylyn.eclipse.org"));
+				assertTrue(matchUserResponse.getAssignedToProposals().contains("guest@mylyn.eclipse.org"));
+				assertNull(matchUserResponse.getNewCCMsg());
+				assertNull(matchUserResponse.getAssignedToMsg());
+				assertNull(matchUserResponse.getQaContactMsg());
+			}
+		}
+	}
+
+	public void testErrorMatchConfirmMatch3() throws Exception {
+		try {
+			doUserMatch("test", "est");
+			fail("CoreException expected but not found");
+		} catch (CoreException e) {
+			if (BugzillaFixture.current().getBugzillaVersion().compareMajorMinorOnly(BugzillaVersion.BUGZILLA_3_6) < 0) {
+				assertEquals(BugzillaStatus.ERROR_MATCH_FAILED, e.getStatus().getCode());
+				BugzillaStatus status = (BugzillaStatus) e.getStatus();
+				assertNotNull(status);
+				BugzillaUserMatchResponse matchUserResponse = status.getUserMatchResponse();
+				assertNotNull(matchUserResponse);
+				assertNotNull(matchUserResponse.getNewCCProposals());
+				assertNotNull(matchUserResponse.getAssignedToProposals());
+				assertNotNull(matchUserResponse.getQaContactProposals());
+				assertEquals(Collections.emptyList(), matchUserResponse.getNewCCProposals());
+				assertEquals(Collections.emptyList(), matchUserResponse.getAssignedToProposals());
+				assertEquals(Collections.emptyList(), matchUserResponse.getQaContactProposals());
+				assertNotNull(matchUserResponse.getNewCCMsg());
+				assertNotNull(matchUserResponse.getAssignedToMsg());
+				assertNull(matchUserResponse.getQaContactMsg());
+				assertTrue(matchUserResponse.getNewCCMsg().equals("test  did not match anything "));
+				assertTrue(matchUserResponse.getAssignedToMsg().equals("est  did not match anything "));
+			} else {
+				assertEquals(BugzillaStatus.ERROR_CONFIRM_MATCH, e.getStatus().getCode());
+				BugzillaStatus status = (BugzillaStatus) e.getStatus();
+				assertNotNull(status);
+				BugzillaUserMatchResponse matchUserResponse = status.getUserMatchResponse();
+				assertNotNull(matchUserResponse);
+				assertNotNull(matchUserResponse.getNewCCProposals());
+				assertNotNull(matchUserResponse.getAssignedToProposals());
+				assertNotNull(matchUserResponse.getQaContactProposals());
+				assertEquals(1, matchUserResponse.getNewCCProposals().size());
+				assertEquals(2, matchUserResponse.getAssignedToProposals().size());
+				assertEquals(Collections.emptyList(), matchUserResponse.getQaContactProposals());
+				assertTrue(matchUserResponse.getNewCCProposals().contains("tests@mylyn.eclipse.org"));
+				assertTrue(matchUserResponse.getAssignedToProposals().contains("tests@mylyn.eclipse.org"));
+				assertTrue(matchUserResponse.getAssignedToProposals().contains("guest@mylyn.eclipse.org"));
+				assertNull(matchUserResponse.getNewCCMsg());
+				assertNull(matchUserResponse.getAssignedToMsg());
+				assertNull(matchUserResponse.getQaContactMsg());
+			}
+		}
+	}
+
+	public void testErrorMatchFailed() throws Exception {
+		try {
+			doUserMatch("tests1@mylyn.eclipse.org", null);
+			fail("CoreException expected but not found");
+		} catch (CoreException e) {
+			assertEquals(BugzillaStatus.ERROR_MATCH_FAILED, e.getStatus().getCode());
+			BugzillaStatus status = (BugzillaStatus) e.getStatus();
+			assertNotNull(status);
+			BugzillaUserMatchResponse matchUserResponse = status.getUserMatchResponse();
+			assertNotNull(matchUserResponse);
+			assertNotNull(matchUserResponse.getNewCCProposals());
+			assertNotNull(matchUserResponse.getAssignedToProposals());
+			assertNotNull(matchUserResponse.getQaContactProposals());
+			assertEquals(Collections.emptyList(), matchUserResponse.getNewCCProposals());
+			assertEquals(Collections.emptyList(), matchUserResponse.getAssignedToProposals());
+			assertEquals(Collections.emptyList(), matchUserResponse.getQaContactProposals());
+			assertNotNull(matchUserResponse.getNewCCMsg());
+			assertNull(matchUserResponse.getAssignedToMsg());
+			assertNull(matchUserResponse.getQaContactMsg());
+			assertTrue(matchUserResponse.getNewCCMsg().equals("tests1@mylyn.eclipse.org  did not match anything "));
+		}
+	}
+
+	public void testErrorMatchFailed2() throws Exception {
+		try {
+			doUserMatch("est", "test1");
+			fail("CoreException expected but not found");
+		} catch (CoreException e) {
+			if (BugzillaFixture.current().getBugzillaVersion().compareMajorMinorOnly(BugzillaVersion.BUGZILLA_3_6) < 0) {
+				assertEquals(BugzillaStatus.ERROR_MATCH_FAILED, e.getStatus().getCode());
+				BugzillaStatus status = (BugzillaStatus) e.getStatus();
+				assertNotNull(status);
+				BugzillaUserMatchResponse matchUserResponse = status.getUserMatchResponse();
+				assertNotNull(matchUserResponse);
+				assertNotNull(matchUserResponse.getNewCCProposals());
+				assertNotNull(matchUserResponse.getAssignedToProposals());
+				assertNotNull(matchUserResponse.getQaContactProposals());
+				assertEquals(Collections.emptyList(), matchUserResponse.getNewCCProposals());
+				assertEquals(Collections.emptyList(), matchUserResponse.getAssignedToProposals());
+				assertEquals(Collections.emptyList(), matchUserResponse.getQaContactProposals());
+				assertNotNull(matchUserResponse.getNewCCMsg());
+				assertNotNull(matchUserResponse.getAssignedToMsg());
+				assertNull(matchUserResponse.getQaContactMsg());
+				assertTrue(matchUserResponse.getNewCCMsg().equals("est  did not match anything "));
+				assertTrue(matchUserResponse.getAssignedToMsg().equals("test1  did not match anything "));
+			} else {
+				assertEquals(BugzillaStatus.ERROR_MATCH_FAILED, e.getStatus().getCode());
+				BugzillaStatus status = (BugzillaStatus) e.getStatus();
+				assertNotNull(status);
+				BugzillaUserMatchResponse matchUserResponse = status.getUserMatchResponse();
+				assertNotNull(matchUserResponse);
+				assertNotNull(matchUserResponse.getNewCCProposals());
+				assertNotNull(matchUserResponse.getAssignedToProposals());
+				assertNotNull(matchUserResponse.getQaContactProposals());
+				assertEquals(2, matchUserResponse.getNewCCProposals().size());
+				assertEquals(Collections.emptyList(), matchUserResponse.getAssignedToProposals());
+				assertEquals(Collections.emptyList(), matchUserResponse.getQaContactProposals());
+				assertTrue(matchUserResponse.getNewCCProposals().contains("tests@mylyn.eclipse.org"));
+				assertTrue(matchUserResponse.getNewCCProposals().contains("guest@mylyn.eclipse.org"));
+				assertNull(matchUserResponse.getNewCCMsg());
+				assertNotNull(matchUserResponse.getAssignedToMsg());
+				assertNull(matchUserResponse.getQaContactMsg());
+			}
+		}
+	}
+
+	public void doUserMatch(String newCCAttributeValue, String assignedToAttributeValue) throws CoreException,
+			IOException {
+		final TaskMapping taskMappingInit = new TaskMapping() {
+
+			@Override
+			public String getProduct() {
+				return "TestProduct";
+			}
+		};
+		final TaskMapping taskMappingSelect = new TaskMapping() {
+			@Override
+			public String getComponent() {
+				return "TestComponent";
+			}
+
+			@Override
+			public String getSummary() {
+				return "test usermatch";
+			}
+
+			@Override
+			public String getDescription() {
+				return "The Description of the usermatch";
+			}
+
+		};
+
+		final TaskData[] taskDataNew = new TaskData[1];
+		// create Task
+		taskDataNew[0] = TasksUiInternal.createTaskData(repository, taskMappingInit, taskMappingSelect, null);
+		ITask taskNew = TasksUiUtil.createOutgoingNewTask(taskDataNew[0].getConnectorKind(),
+				taskDataNew[0].getRepositoryUrl());
+
+		ITaskDataWorkingCopy workingCopy = TasksUi.getTaskDataManager().createWorkingCopy(taskNew, taskDataNew[0]);
+		Set<TaskAttribute> changed = new HashSet<TaskAttribute>();
+		workingCopy.save(changed, null);
+
+		RepositoryResponse response = BugzillaFixture.current().submitTask(taskDataNew[0], client);//connector.getTaskDataHandler().postTaskData(repository, taskDataNew[0], changed,
+		//new NullProgressMonitor());
+		((AbstractTask) taskNew).setSubmitting(true);
+
+		assertNotNull(response);
+		assertEquals(ResponseKind.TASK_CREATED.toString(), response.getReposonseKind().toString());
+		String taskId = response.getTaskId();
+
+		ITask task = generateLocalTaskAndDownload(taskId);
+		assertNotNull(task);
+		TaskDataModel model = createModel(task);
+		TaskData taskData = model.getTaskData();
+		assertNotNull(taskData);
+		TaskAttribute newCCAttribute = taskData.getRoot().getAttribute(BugzillaAttribute.NEWCC.getKey());
+		TaskAttribute assignedToAttribute = taskData.getRoot().getAttribute(BugzillaAttribute.ASSIGNED_TO.getKey());
+		changed.clear();
+		if (newCCAttribute != null && newCCAttributeValue != null) {
+			newCCAttribute.setValue(newCCAttributeValue);
+			model.attributeChanged(newCCAttribute);
+			changed.add(newCCAttribute);
+		}
+		if (assignedToAttribute != null && assignedToAttributeValue != null) {
+			assignedToAttribute.setValue(assignedToAttributeValue);
+			model.attributeChanged(assignedToAttribute);
+			changed.add(assignedToAttribute);
+		}
+		workingCopy.save(changed, null);
+		response = BugzillaFixture.current().submitTask(taskData, client);
+	}
+
+	public void testPrivateDescription() throws Exception {
+		final TaskMapping taskMappingInit = new TaskMapping() {
+
+			@Override
+			public String getProduct() {
+				return "TestProduct";
+			}
+		};
+		final TaskMapping taskMappingSelect = new TaskMapping() {
+			@Override
+			public String getComponent() {
+				return "TestComponent";
+			}
+
+			@Override
+			public String getSummary() {
+				return "test private comments";
+			}
+
+			@Override
+			public String getDescription() {
+				return "The Description of the private comments task";
+			}
+
+		};
+		if (BugzillaFixture.current().equals(BugzillaFixture.BUGS_3_4)) {
+			return;
+		}
+		final TaskData[] taskDataNew = new TaskData[1];
+		// create Task
+		taskDataNew[0] = TasksUiInternal.createTaskData(repository, taskMappingInit, taskMappingSelect, null);
+		ITask taskNew = TasksUiUtil.createOutgoingNewTask(taskDataNew[0].getConnectorKind(),
+				taskDataNew[0].getRepositoryUrl());
+
+		ITaskDataWorkingCopy workingCopy = TasksUi.getTaskDataManager().createWorkingCopy(taskNew, taskDataNew[0]);
+		Set<TaskAttribute> changed = new HashSet<TaskAttribute>();
+		workingCopy.save(changed, null);
+
+		RepositoryResponse response = BugzillaFixture.current().submitTask(taskDataNew[0], client);//connector.getTaskDataHandler().postTaskData(repository, taskDataNew[0], changed,
+		//new NullProgressMonitor());
+		((AbstractTask) taskNew).setSubmitting(true);
+
+		assertNotNull(response);
+		assertEquals(ResponseKind.TASK_CREATED.toString(), response.getReposonseKind().toString());
+		String taskId = response.getTaskId();
+
+		ITask task = generateLocalTaskAndDownload(taskId);
+		assertNotNull(task);
+		TaskDataModel model = createModel(task);
+		TaskData taskData = model.getTaskData();
+		assertNotNull(taskData);
+		TaskAttribute description = taskData.getRoot().getAttribute(BugzillaAttribute.LONG_DESC.getKey());
+		TaskAttribute isPrivateAttribute = description.getAttribute(IBugzillaConstants.BUGZILLA_DESCRIPTION_IS_PRIVATE);
+		assertEquals("0", isPrivateAttribute.getValue());
+		TaskAttribute idAttribute = description.getAttribute(IBugzillaConstants.BUGZILLA_DESCRIPTION_ID);
+
+		String value = idAttribute.getValue();
+		TaskAttribute definedIsPrivate = description.getAttribute(IBugzillaConstants.BUGZILLA_PREFIX_DEFINED_ISPRIVATE
+				+ value);
+		if (definedIsPrivate == null) {
+			definedIsPrivate = description.createAttribute(IBugzillaConstants.BUGZILLA_PREFIX_DEFINED_ISPRIVATE + value);
+		}
+		TaskAttribute isPrivate = description.getAttribute(IBugzillaConstants.BUGZILLA_PREFIX_ISPRIVATE + value);
+		if (isPrivate == null) {
+			isPrivate = description.createAttribute(IBugzillaConstants.BUGZILLA_PREFIX_ISPRIVATE + value);
+		}
+		definedIsPrivate.setValue("1"); //$NON-NLS-1$
+		isPrivate.setValue("1"); //$NON-NLS-1$ 
+
+		model.attributeChanged(description);
+		changed.clear();
+		changed.add(description);
+		workingCopy.save(changed, null);
+		response = BugzillaFixture.current().submitTask(taskData, client);
+
+		task = generateLocalTaskAndDownload(taskId);
+		assertNotNull(task);
+		model = createModel(task);
+		taskData = model.getTaskData();
+		assertNotNull(taskData);
+		description = taskData.getRoot().getAttribute(BugzillaAttribute.LONG_DESC.getKey());
+		isPrivateAttribute = description.getAttribute(IBugzillaConstants.BUGZILLA_DESCRIPTION_IS_PRIVATE);
+		assertEquals("1", isPrivateAttribute.getValue());
+	}
+
+	public void testPrivateComments() throws Exception {
+		final TaskMapping taskMappingInit = new TaskMapping() {
+
+			@Override
+			public String getProduct() {
+				return "TestProduct";
+			}
+		};
+		final TaskMapping taskMappingSelect = new TaskMapping() {
+			@Override
+			public String getComponent() {
+				return "TestComponent";
+			}
+
+			@Override
+			public String getSummary() {
+				return "test private comments";
+			}
+
+			@Override
+			public String getDescription() {
+				return "The Description of the private comments task";
+			}
+
+		};
+		if (BugzillaFixture.current().equals(BugzillaFixture.BUGS_3_4)) {
+			return;
+		}
+
+		final TaskData[] taskDataNew = new TaskData[1];
+		// create Task
+		taskDataNew[0] = TasksUiInternal.createTaskData(repository, taskMappingInit, taskMappingSelect, null);
+		ITask taskNew = TasksUiUtil.createOutgoingNewTask(taskDataNew[0].getConnectorKind(),
+				taskDataNew[0].getRepositoryUrl());
+
+		ITaskDataWorkingCopy workingCopy = TasksUi.getTaskDataManager().createWorkingCopy(taskNew, taskDataNew[0]);
+		Set<TaskAttribute> changed = new HashSet<TaskAttribute>();
+		workingCopy.save(changed, null);
+
+		RepositoryResponse response = BugzillaFixture.current().submitTask(taskDataNew[0], client);//connector.getTaskDataHandler().postTaskData(repository, taskDataNew[0], changed,
+		//new NullProgressMonitor());
+		((AbstractTask) taskNew).setSubmitting(true);
+
+		assertNotNull(response);
+		assertEquals(ResponseKind.TASK_CREATED.toString(), response.getReposonseKind().toString());
+		String taskId = response.getTaskId();
+
+		ITask task = generateLocalTaskAndDownload(taskId);
+		assertNotNull(task);
+		TaskDataModel model = createModel(task);
+		TaskData taskData = model.getTaskData();
+		assertNotNull(taskData);
+
+		TaskAttribute newComment = taskData.getRoot().getAttribute(BugzillaAttribute.NEW_COMMENT.getKey());
+		newComment.setValue("New Comment");
+
+		model.attributeChanged(newComment);
+		changed.clear();
+		changed.add(newComment);
+		workingCopy.save(changed, null);
+		response = BugzillaFixture.current().submitTask(taskData, client);
+
+		task = generateLocalTaskAndDownload(taskId);
+		assertNotNull(task);
+		model = createModel(task);
+		taskData = model.getTaskData();
+		assertNotNull(taskData);
+		TaskAttribute comment1 = taskData.getRoot().getAttribute("task.common.comment-1");
+		TaskAttribute isPrivateAttribute = comment1.getAttribute(IBugzillaConstants.BUGZILLA_DESCRIPTION_IS_PRIVATE);
+		assertEquals("0", isPrivateAttribute.getValue());
+
+		String value = comment1.getValue();
+		TaskAttribute definedIsPrivate = comment1.getAttribute(IBugzillaConstants.BUGZILLA_PREFIX_DEFINED_ISPRIVATE
+				+ value);
+		if (definedIsPrivate == null) {
+			definedIsPrivate = comment1.createAttribute(IBugzillaConstants.BUGZILLA_PREFIX_DEFINED_ISPRIVATE + value);
+		}
+		TaskAttribute isPrivate = comment1.getAttribute(IBugzillaConstants.BUGZILLA_PREFIX_ISPRIVATE + value);
+		if (isPrivate == null) {
+			isPrivate = comment1.createAttribute(IBugzillaConstants.BUGZILLA_PREFIX_ISPRIVATE + value);
+		}
+		definedIsPrivate.setValue("1"); //$NON-NLS-1$
+		isPrivate.setValue("1"); //$NON-NLS-1$ 
+
+		model.attributeChanged(comment1);
+		changed.clear();
+		changed.add(comment1);
+		workingCopy.save(changed, null);
+		response = BugzillaFixture.current().submitTask(taskData, client);
+
+		task = generateLocalTaskAndDownload(taskId);
+		assertNotNull(task);
+		model = createModel(task);
+		taskData = model.getTaskData();
+		assertNotNull(taskData);
+		comment1 = taskData.getRoot().getAttribute("task.common.comment-1");
+		isPrivateAttribute = comment1.getAttribute(IBugzillaConstants.BUGZILLA_DESCRIPTION_IS_PRIVATE);
+		assertEquals("1", isPrivateAttribute.getValue());
+	}
+
 }
