@@ -11,6 +11,8 @@
 
 package org.eclipse.mylyn.internal.bugzilla.ui.editor;
 
+import java.text.MessageFormat;
+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
@@ -21,21 +23,28 @@ import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.NullProgressMonitor;
 import org.eclipse.jface.dialogs.IMessageProvider;
+import org.eclipse.jface.fieldassist.ControlDecoration;
+import org.eclipse.jface.fieldassist.FieldDecoration;
+import org.eclipse.jface.fieldassist.FieldDecorationRegistry;
 import org.eclipse.mylyn.commons.core.StatusHandler;
 import org.eclipse.mylyn.commons.net.AuthenticationCredentials;
 import org.eclipse.mylyn.commons.net.AuthenticationType;
+import org.eclipse.mylyn.commons.workbench.WorkbenchUtil;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaAttribute;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaCorePlugin;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaCustomField;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaOperation;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaRepositoryConnector;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaRepositoryResponse;
+import org.eclipse.mylyn.internal.bugzilla.core.BugzillaStatus;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaTaskDataHandler;
+import org.eclipse.mylyn.internal.bugzilla.core.BugzillaUserMatchResponse;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaVersion;
 import org.eclipse.mylyn.internal.bugzilla.core.IBugzillaConstants;
 import org.eclipse.mylyn.internal.bugzilla.core.RepositoryConfiguration;
 import org.eclipse.mylyn.internal.bugzilla.ui.BugzillaUiPlugin;
-import org.eclipse.mylyn.internal.provisional.commons.ui.WorkbenchUtil;
+import org.eclipse.mylyn.internal.tasks.ui.PersonProposalProvider;
+import org.eclipse.mylyn.internal.tasks.ui.editors.PersonAttributeEditor;
 import org.eclipse.mylyn.internal.tasks.ui.editors.TaskEditorActionPart;
 import org.eclipse.mylyn.tasks.core.RepositoryResponse;
 import org.eclipse.mylyn.tasks.core.RepositoryStatus;
@@ -57,12 +66,21 @@ import org.eclipse.mylyn.tasks.ui.editors.LayoutHint;
 import org.eclipse.mylyn.tasks.ui.editors.TaskEditor;
 import org.eclipse.mylyn.tasks.ui.editors.TaskEditorInput;
 import org.eclipse.mylyn.tasks.ui.editors.TaskEditorPartDescriptor;
+import org.eclipse.osgi.util.NLS;
+import org.eclipse.swt.SWT;
+import org.eclipse.swt.events.ModifyEvent;
+import org.eclipse.swt.events.ModifyListener;
+import org.eclipse.swt.widgets.Control;
 import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.fieldassist.ContentAssistCommandAdapter;
 import org.eclipse.ui.forms.events.HyperlinkAdapter;
 import org.eclipse.ui.forms.events.HyperlinkEvent;
+import org.eclipse.ui.forms.widgets.ExpandableComposite;
+import org.eclipse.ui.keys.IBindingService;
 
 /**
  * @author Rob Elves
+ * @author Frank Becker
  * @since 3.0
  */
 public class BugzillaTaskEditorPage extends AbstractTaskEditorPage {
@@ -77,6 +95,10 @@ public class BugzillaTaskEditorPage extends AbstractTaskEditorPage {
 
 	private TaskDataModelListener productListener;
 
+	private final List<ControlDecoration> errorDecorations = new ArrayList<ControlDecoration>();
+
+	private final List<PersonAttributeEditor> editorsWithError = new ArrayList<PersonAttributeEditor>(3);
+
 	public BugzillaTaskEditorPage(TaskEditor editor) {
 		this(editor, BugzillaCorePlugin.CONNECTOR_KIND);
 	}
@@ -97,7 +119,9 @@ public class BugzillaTaskEditorPage extends AbstractTaskEditorPage {
 	@Override
 	protected Set<TaskEditorPartDescriptor> createPartDescriptors() {
 		Set<TaskEditorPartDescriptor> descriptors = super.createPartDescriptors();
-
+		boolean hasPartComments = false;
+		boolean hasPartNewComment = false;
+		boolean hasPartDescription = false;
 		// remove unnecessary default editor parts
 		for (TaskEditorPartDescriptor taskEditorPartDescriptor : descriptors) {
 			if (taskEditorPartDescriptor.getId().equals(ID_PART_PEOPLE)) {
@@ -105,6 +129,27 @@ public class BugzillaTaskEditorPage extends AbstractTaskEditorPage {
 				break;
 			}
 		}
+		for (TaskEditorPartDescriptor taskEditorPartDescriptor : descriptors) {
+			if (taskEditorPartDescriptor.getId().equals(ID_PART_COMMENTS)) {
+				descriptors.remove(taskEditorPartDescriptor);
+				hasPartComments = true;
+				break;
+			}
+		}
+		for (TaskEditorPartDescriptor taskEditorPartDescriptor : descriptors) {
+			if (taskEditorPartDescriptor.getId().equals(ID_PART_NEW_COMMENT)) {
+				descriptors.remove(taskEditorPartDescriptor);
+				hasPartNewComment = true;
+				break;
+			}
+		}
+		for (TaskEditorPartDescriptor taskEditorPartDescriptor : descriptors) {
+			if (taskEditorPartDescriptor.getId().equals(ID_PART_DESCRIPTION)) {
+				descriptors.remove(taskEditorPartDescriptor);
+				hasPartDescription = true;
+				break;
+			}
+		}
 
 		// Add Bugzilla Planning part
 		try {
@@ -135,10 +180,42 @@ public class BugzillaTaskEditorPage extends AbstractTaskEditorPage {
 					}.setPath(ID_PART_ATTRIBUTES + "/" + PATH_PLANNING)); //$NON-NLS-1$
 				}
 			}
+			if (hasPartDescription) {
+				descriptors.add(new TaskEditorPartDescriptor(ID_PART_DESCRIPTION) {
+					@Override
+					public AbstractTaskEditorPart createPart() {
+						BugzillaTaskEditorDescriptionPart part = new BugzillaTaskEditorDescriptionPart();
+						if (getModel().getTaskData().isNew()) {
+							part.setExpandVertically(true);
+							part.setSectionStyle(ExpandableComposite.TITLE_BAR | ExpandableComposite.EXPANDED);
+						}
+						return part;
+					}
+				}.setPath(PATH_COMMENTS));
+
+			}
+			if (hasPartComments) {
+				descriptors.add(new TaskEditorPartDescriptor(ID_PART_COMMENTS) {
+					@Override
+					public AbstractTaskEditorPart createPart() {
+						return new BugzillaTaskEditorCommentPart();
+					}
+				}.setPath(PATH_COMMENTS));
+
+			}
 		} catch (CoreException e) {
 			// ignore
 		}
 
+		if (hasPartNewComment) {
+			// Add the updated Bugzilla new comment part
+			descriptors.add(new TaskEditorPartDescriptor(ID_PART_NEW_COMMENT) {
+				@Override
+				public AbstractTaskEditorPart createPart() {
+					return new BugzillaTaskEditorNewCommentPart();
+				}
+			}.setPath(PATH_COMMENTS));
+		}
 		// Add the updated Bugzilla people part
 		descriptors.add(new TaskEditorPartDescriptor(ID_PART_PEOPLE) {
 			@Override
@@ -295,6 +372,12 @@ public class BugzillaTaskEditorPage extends AbstractTaskEditorPage {
 				attrToken.setValue(tokenString);
 			}
 		}
+		for (ControlDecoration decoration : errorDecorations) {
+			decoration.hide();
+			decoration.dispose();
+		}
+		errorDecorations.clear();
+		editorsWithError.clear();
 		if (!checkCanSubmit(IMessageProvider.ERROR)) {
 			return;
 		}
@@ -464,6 +547,14 @@ public class BugzillaTaskEditorPage extends AbstractTaskEditorPage {
 
 	@Override
 	protected void handleTaskSubmitted(SubmitJobEvent event) {
+		if (event.getJob().getStatus() != null) {
+			switch (event.getJob().getStatus().getCode()) {
+			case BugzillaStatus.ERROR_CONFIRM_MATCH:
+			case BugzillaStatus.ERROR_MATCH_FAILED:
+				showError((BugzillaStatus) event.getJob().getStatus());
+				return;
+			}
+		}
 		if (event.getJob().getResponse() != null && event.getJob().getResponse() instanceof BugzillaRepositoryResponse) {
 			final RepositoryResponse response = event.getJob().getResponse();
 			if (response instanceof BugzillaRepositoryResponse) {
@@ -473,10 +564,9 @@ public class BugzillaTaskEditorPage extends AbstractTaskEditorPage {
 							IMessageProvider.INFORMATION, new HyperlinkAdapter() {
 								@Override
 								public void linkActivated(HyperlinkEvent event) {
-									BugzillaResponseDetailDialog dialog = new BugzillaResponseDetailDialog(
-											WorkbenchUtil.getShell(), bugzillaResponse);
-									dialog.open();
+									showSubmitResponse(bugzillaResponse);
 								}
+
 							});
 				} else {
 					getTaskEditor().setMessage(Messages.BugzillaTaskEditorPage_Changes_Submitted_Message,
@@ -512,46 +602,190 @@ public class BugzillaTaskEditorPage extends AbstractTaskEditorPage {
 			});
 			return false;
 		}
-//		if (!getModel().getTaskData().isNew()) {
-//			TaskAttribute exporter = getModel().getTaskData()
-//					.getRoot()
-//					.getAttribute(BugzillaAttribute.EXPORTER_NAME.getKey());
-//			if (exporter == null) {
-//				PlatformUI.getWorkbench().getDisplay().asyncExec(new Runnable() {
-//					public void run() {
-//						getTaskEditor().setMessage(Messages.BugzillaTaskEditorPage_submit_disabled_please_refresh,
-//								type, new HyperlinkAdapter() {
-//									@Override
-//									public void linkActivated(HyperlinkEvent e) {
-//										ITask task = getModel().getTask();
-//										AbstractRepositoryConnector connector = TasksUi.getRepositoryManager()
-//												.getRepositoryConnector(task.getConnectorKind());
-//										if (connector == null) {
-//											return;
-//										}
-//										TasksUiInternal.synchronizeTask(connector, task, true, new JobChangeAdapter() {
-//											@Override
-//											public void done(IJobChangeEvent event) {
-//												PlatformUI.getWorkbench().getDisplay().asyncExec(new Runnable() {
-//													public void run() {
-//														try {
-//															getTaskEditor().refreshPages();
-//														} finally {
-//															if (getTaskEditor() != null) {
-//																getTaskEditor().showBusy(false);
-//															}
-//														}
-//													}
-//												});
-//											}
-//										});
-//									}
-//								});
-//					}
-//				});
-//				return false;
-//			}
-//		}
+		if (!getModel().getTaskData().isNew()) {
+			TaskAttribute exporter = getModel().getTaskData()
+					.getRoot()
+					.getAttribute(BugzillaAttribute.EXPORTER_NAME.getKey());
+			if (exporter == null || exporter.getValue().equals("")) { //$NON-NLS-1$
+				PlatformUI.getWorkbench().getDisplay().asyncExec(new Runnable() {
+					public void run() {
+						getTaskEditor().setMessage(Messages.BugzillaTaskEditorPage_submit_disabled_please_refresh,
+								type, new HyperlinkAdapter() {
+									@Override
+									public void linkActivated(HyperlinkEvent e) {
+										TasksUiUtil.openEditRepositoryWizard(taskRepository);
+										refresh();
+									}
+								});
+					}
+				});
+				return false;
+			}
+		}
 		return true;
 	}
+
+	private void showError(BugzillaStatus bugzillaStatus) {
+		int count = 0;
+		BugzillaUserMatchResponse response = bugzillaStatus.getUserMatchResponse();
+		FieldDecorationRegistry registry = FieldDecorationRegistry.getDefault();
+		FieldDecoration fieldDecoration = registry.getFieldDecoration(FieldDecorationRegistry.DEC_ERROR);
+		StringBuilder fields = new StringBuilder();
+		StringBuilder detail = new StringBuilder();
+
+		count += decorateControlsAndUpdateMessages(response.getAssignedToMsg(), response.getAssignedToProposals(),
+				getModel().getTaskData().getRoot().getAttribute(BugzillaAttribute.ASSIGNED_TO.getKey()), fields,
+				detail, fieldDecoration);
+		count += decorateControlsAndUpdateMessages(response.getQaContactMsg(), response.getQaContactProposals(),
+				getModel().getTaskData().getRoot().getAttribute(BugzillaAttribute.QA_CONTACT.getKey()), fields, detail,
+				fieldDecoration);
+		count += decorateControlsAndUpdateMessages(response.getNewCCMsg(), response.getNewCCProposals(),
+				getModel().getTaskData().getRoot().getAttribute(BugzillaAttribute.NEWCC.getKey()), fields, detail,
+				fieldDecoration);
+		updateTaskEditorPageMessageWithError(bugzillaStatus, detail.toString(), count == 1, fields.toString());
+	}
+
+	private int decorateControlsAndUpdateMessages(String message, List<String> proposals, TaskAttribute attribute,
+			StringBuilder fields, StringBuilder detail, FieldDecoration fieldDecoration) {
+		if (attribute == null || (message == null && proposals.size() == 0)) {
+			return 0;
+		}
+		Map<String, String> newPersonProposalMap = new HashMap<String, String>();
+		if (fields.length() > 0) {
+			fields.append(MessageFormat.format(Messages.BugzillaTaskEditorPage_Error_Label_N, attribute.getMetaData()
+					.getLabel()));
+		} else {
+			fields.append(MessageFormat.format(Messages.BugzillaTaskEditorPage_Error_Label_1, attribute.getMetaData()
+					.getLabel()));
+		}
+		detail.append(attribute.getMetaData().getLabel() + "\n"); //$NON-NLS-1$
+		if (message != null && !message.equals("")) { //$NON-NLS-1$
+			detail.append(MessageFormat.format(Messages.BugzillaTaskEditorPage_DetailLine, message));
+		} else {
+			for (String proposalValue : proposals) {
+				detail.append(MessageFormat.format(Messages.BugzillaTaskEditorPage_DetailLine, proposalValue));
+				newPersonProposalMap.put(proposalValue, proposalValue);
+			}
+		}
+		AbstractAttributeEditor editor = getEditorForAttribute(attribute);
+		if (editor != null) {
+			decorateEditorWithError(fieldDecoration, message, newPersonProposalMap, editor);
+		}
+		return 1;
+	}
+
+	/**
+	 * @param bugzillaStatus
+	 * @param resultDetail
+	 * @param oneError
+	 * @param fieldString
+	 */
+	private void updateTaskEditorPageMessageWithError(BugzillaStatus bugzillaStatus, String resultDetail,
+			boolean oneError, String fieldString) {
+		String resultString;
+		final String titleString;
+		switch (bugzillaStatus.getCode()) {
+		case BugzillaStatus.ERROR_CONFIRM_MATCH:
+			if (oneError) {
+				resultString = MessageFormat.format(Messages.BugzillaTaskEditorPage_Message_one,
+						Messages.BugzillaTaskEditorPage_Confirm, fieldString);
+			} else {
+				resultString = MessageFormat.format(Messages.BugzillaTaskEditorPage_Message_more,
+						Messages.BugzillaTaskEditorPage_Confirm, fieldString);
+			}
+			titleString = Messages.BugzillaTaskEditorPage_ConfirmDetailTitle;
+			break;
+		case BugzillaStatus.ERROR_MATCH_FAILED:
+			if (oneError) {
+				resultString = MessageFormat.format(Messages.BugzillaTaskEditorPage_Message_one,
+						Messages.BugzillaTaskEditorPage_Error, fieldString);
+			} else {
+				resultString = MessageFormat.format(Messages.BugzillaTaskEditorPage_Message_more,
+						Messages.BugzillaTaskEditorPage_Error, fieldString);
+			}
+			titleString = Messages.BugzillaTaskEditorPage_ErrorDetailTitle;
+			break;
+		default:
+			throw new RuntimeException("unexpected BugzillaStatus: " + bugzillaStatus.getCode()); //$NON-NLS-1$
+		}
+
+		final String resultDetailString = resultDetail;
+		getTaskEditor().setMessage(resultString, IMessageProvider.ERROR, new HyperlinkAdapter() {
+			@Override
+			public void linkActivated(HyperlinkEvent event) {
+				BugzillaResponseDetailDialog dialog = new BugzillaResponseDetailDialog(WorkbenchUtil.getShell(),
+						titleString, resultDetailString);
+				dialog.open();
+			}
+		});
+	}
+
+	/**
+	 * @param fieldDecoration
+	 * @param message
+	 * @param newPersonProposalMap
+	 * @param editor
+	 */
+	private void decorateEditorWithError(FieldDecoration fieldDecoration, String message,
+			Map<String, String> newPersonProposalMap, AbstractAttributeEditor editor) {
+		final Control control = editor.getControl();
+
+		final ControlDecoration decoration = new ControlDecoration(control, SWT.LEFT | SWT.DOWN);
+		decoration.setImage(fieldDecoration.getImage());
+		IBindingService bindingService = (IBindingService) PlatformUI.getWorkbench().getService(IBindingService.class);
+		if (message != null && !message.equals("")) { //$NON-NLS-1$
+			decoration.setDescriptionText(message);
+			errorDecorations.add(decoration);
+		} else {
+			decoration.setDescriptionText(NLS.bind(
+					Messages.BugzillaTaskEditorPage_Content_Assist_for_Error_Available,
+					bindingService.getBestActiveBindingFormattedFor(ContentAssistCommandAdapter.CONTENT_PROPOSAL_COMMAND)));
+			errorDecorations.add(decoration);
+
+			PersonAttributeEditor personEditor = ((PersonAttributeEditor) editor);
+			final PersonProposalProvider personProposalProvider = (PersonProposalProvider) personEditor.getContentAssistCommandAdapter()
+					.getContentProposalProvider();
+			personProposalProvider.setErrorProposals(newPersonProposalMap);
+
+			editorsWithError.add(personEditor);
+			if (newPersonProposalMap.size() == 1) {
+				personEditor.setValue(newPersonProposalMap.keySet().iterator().next());
+
+			}
+			personEditor.getText().addModifyListener(new ModifyListener() {
+
+				public void modifyText(ModifyEvent e) {
+					decoration.hide();
+					errorDecorations.remove(decoration);
+					decoration.dispose();
+					personProposalProvider.setErrorProposals(null);
+				}
+			});
+		}
+	}
+
+	/**
+	 * @param bugzillaResponse
+	 */
+	private void showSubmitResponse(final BugzillaRepositoryResponse bugzillaResponse) {
+		StringBuilder message = new StringBuilder();
+		for (String iterable_map : bugzillaResponse.getResponseData().keySet()) {
+			if (message.length() > 0) {
+				message.append("\n"); //$NON-NLS-1$
+			}
+			message.append(NLS.bind(Messages.BugzillaTaskEditorPage_Bug_Line, iterable_map));
+			Map<String, List<String>> responseMap = bugzillaResponse.getResponseData().get(iterable_map);
+			for (String iterable_list : responseMap.keySet()) {
+				message.append(NLS.bind(Messages.BugzillaTaskEditorPage_Action_Line, iterable_list));
+				List<String> responseList = responseMap.get(iterable_list);
+				for (String string : responseList) {
+					message.append(NLS.bind(Messages.BugzillaTaskEditorPage_Email_Line, string));
+				}
+			}
+		}
+		BugzillaResponseDetailDialog dialog = new BugzillaResponseDetailDialog(WorkbenchUtil.getShell(),
+				Messages.BugzillaTaskEditorPage_submitted_Changes_Details, message.toString());
+		dialog.open();
+	}
+
 }
