@@ -32,6 +32,7 @@ import org.eclipse.jface.layout.GridDataFactory;
 import org.eclipse.jface.operation.IRunnableWithProgress;
 import org.eclipse.mylyn.commons.net.AuthenticationCredentials;
 import org.eclipse.mylyn.commons.net.AuthenticationType;
+import org.eclipse.mylyn.commons.workbench.WorkbenchUtil;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaClient;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaClientFactory;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaCorePlugin;
@@ -40,7 +41,6 @@ import org.eclipse.mylyn.internal.bugzilla.core.BugzillaRepositoryConnector;
 import org.eclipse.mylyn.internal.bugzilla.core.BugzillaStatus;
 import org.eclipse.mylyn.internal.bugzilla.core.IBugzillaConstants;
 import org.eclipse.mylyn.internal.bugzilla.core.RepositoryConfiguration;
-import org.eclipse.mylyn.internal.provisional.commons.ui.WorkbenchUtil;
 import org.eclipse.mylyn.internal.tasks.core.IRepositoryConstants;
 import org.eclipse.mylyn.internal.tasks.core.RepositoryTemplateManager;
 import org.eclipse.mylyn.internal.tasks.ui.TasksUiPlugin;
@@ -123,12 +123,15 @@ public class BugzillaRepositorySettingsPage extends AbstractRepositorySettingsPa
 
 	private Button use_see_also;
 
+	private Button insidergroup;
+
 	public BugzillaRepositorySettingsPage(TaskRepository taskRepository) {
 		super(TITLE, DESCRIPTION, taskRepository);
 		setNeedsAnonymousLogin(true);
 		setNeedsEncoding(true);
 		setNeedsTimeZone(false);
 		setNeedsHttpAuth(true);
+		setNeedsValidateOnFinish(true);
 	}
 
 	@Override
@@ -260,6 +263,14 @@ public class BugzillaRepositorySettingsPage extends AbstractRepositorySettingsPa
 		for (BugzillaLanguageSettings bugzillaLanguageSettings : BugzillaRepositoryConnector.getLanguageSettings()) {
 			languageSettingCombo.add(bugzillaLanguageSettings.getLanguageName());
 		}
+		Label insidergroupLabel = new Label(parent, SWT.NONE);
+		insidergroupLabel.setText(Messages.BugzillaRepositorySettingsPage_insiderGroup);
+		insidergroupLabel.setToolTipText(Messages.BugzillaRepositorySettingsPage_insiderGroup_ToolTip);
+		insidergroup = new Button(parent, SWT.CHECK);
+		if (repository != null) {
+			boolean insider = Boolean.parseBoolean(repository.getProperty(IBugzillaConstants.BUGZILLA_INSIDER_GROUP));
+			insidergroup.setSelection(insider);
+		}
 
 		Group workflowGroup = new Group(parent, SWT.SHADOW_ETCHED_IN);
 		workflowGroup.setLayout(new GridLayout(2, false));
@@ -519,7 +530,6 @@ public class BugzillaRepositorySettingsPage extends AbstractRepositorySettingsPa
 		defaultPlatformCombo.setEnabled(!autodetectPlatformOS.getSelection());
 	}
 
-	@SuppressWarnings({ "restriction" })
 	@Override
 	public void applyTo(final TaskRepository repository) {
 		AuthenticationCredentials repositoryAuth = repository.getCredentials(AuthenticationType.REPOSITORY);
@@ -599,11 +609,6 @@ public class BugzillaRepositorySettingsPage extends AbstractRepositorySettingsPa
 		}
 	}
 
-	@Override
-	protected boolean isValidUrl(String url) {
-		return BugzillaClient.isValidUrl(url);
-	}
-
 	@Override
 	protected Validator getValidator(TaskRepository repository) {
 		return new BugzillaValidator(repository);
@@ -721,6 +726,7 @@ public class BugzillaRepositorySettingsPage extends AbstractRepositorySettingsPa
 				Boolean.toString(!usebugaliases.getSelection()));
 		repository.setProperty(IBugzillaConstants.BUGZILLA_PARAM_USE_SEE_ALSO,
 				Boolean.toString(!use_see_also.getSelection()));
+		repository.setProperty(IBugzillaConstants.BUGZILLA_INSIDER_GROUP, Boolean.toString(insidergroup.getSelection()));
 	}
 
 	@Override
