@@ -7,6 +7,7 @@
  *
  * Contributors:
  *     Tasktop Technologies - initial API and implementation
+ *     Manuel Doninger - fixes for bug 349924
  *******************************************************************************/
 
 package org.eclipse.mylyn.internal.tasks.core;
@@ -26,7 +27,12 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.CopyOnWriteArraySet;
 
 import org.eclipse.core.runtime.Assert;
+import org.eclipse.core.runtime.IConfigurationElement;
+import org.eclipse.core.runtime.IExtension;
+import org.eclipse.core.runtime.IExtensionPoint;
+import org.eclipse.core.runtime.IExtensionRegistry;
 import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.Platform;
 import org.eclipse.core.runtime.Status;
 import org.eclipse.mylyn.commons.core.StatusHandler;
 import org.eclipse.mylyn.internal.tasks.core.TaskContainerDelta.Kind;
@@ -34,6 +40,7 @@ import org.eclipse.mylyn.tasks.core.ITask;
 import org.eclipse.mylyn.tasks.core.ITaskActivationListener;
 import org.eclipse.mylyn.tasks.core.ITaskActivityListener;
 import org.eclipse.mylyn.tasks.core.ITaskActivityManager;
+import org.eclipse.osgi.util.NLS;
 
 /**
  * Manages task elapsed time, scheduling, due dates, and the date ranges
@@ -73,6 +80,8 @@ public class TaskActivityManager implements ITaskActivityManager {
 
 	private int startDay = Calendar.MONDAY;
 
+	private boolean listenersInitialized = false;
+
 	private final ITaskListChangeListener TASKLIST_CHANGE_LISTENER = new ITaskListChangeListener() {
 
 		public void containersChanged(Set<TaskContainerDelta> containers) {
@@ -87,6 +96,9 @@ public class TaskActivityManager implements ITaskActivityManager {
 		}
 	};
 
+	private static final String ID_EXTENSION_TASK_ACTIVATION_LISTENERS = ITasksCoreConstants.ID_PLUGIN
+			+ ".taskActivationListeners"; //$NON-NLS-1$
+
 	public TaskActivityManager(TaskRepositoryManager repositoryManager, TaskList taskList) {
 		this.taskList = taskList;
 		this.repositoryManager = repositoryManager;
@@ -94,6 +106,46 @@ public class TaskActivityManager implements ITaskActivityManager {
 		clear();
 	}
 
+	/**
+	 * Reads task activation listeners from an extension point.
+	 * <p>
+	 * Note: The method is not synchronizes since task activation and de-activation are expected to occur sequentially.
+	 */
+	private void initTaskListeners() {
+		if (!listenersInitialized) {
+			listenersInitialized = true;
+
+			IExtensionRegistry registry = Platform.getExtensionRegistry();
+			IExtensionPoint listenerExtensionPoint = registry.getExtensionPoint(TaskActivityManager.ID_EXTENSION_TASK_ACTIVATION_LISTENERS);
+			IExtension[] listenerExtensions = listenerExtensionPoint.getExtensions();
+			for (IExtension extension : listenerExtensions) {
+				IConfigurationElement[] elements = extension.getConfigurationElements();
+				for (IConfigurationElement element : elements) {
+					if ("listener".equals(element.getName())) { //$NON-NLS-1$
+						try {
+							Object object = element.createExecutableExtension("class"); //$NON-NLS-1$
+							if (object instanceof ITaskActivationListener) {
+								addActivationListener((ITaskActivationListener) object);
+							} else {
+								StatusHandler.log(new Status(
+										IStatus.ERROR,
+										ITasksCoreConstants.ID_PLUGIN,
+										NLS.bind(
+												"Unexpected error registering listener contributed by {0}: ''{1}'' does not extend expected class", //$NON-NLS-1$
+												element.getContributor().getName(), object.getClass()
+														.getCanonicalName())));
+							}
+						} catch (Throwable e) {
+							StatusHandler.log(new Status(IStatus.ERROR, ITasksCoreConstants.ID_PLUGIN, NLS.bind(
+									"Unexpected error registering listener contributed by {0}", //$NON-NLS-1$
+									element.getContributor().getName()), e));
+						}
+					}
+				}
+			}
+		}
+	}
+
 	/**
 	 * Get the user specified first day of the week (Calendar.SUNDAY | Calendar.MONDAY)
 	 * 
@@ -407,6 +459,8 @@ public class TaskActivityManager implements ITaskActivityManager {
 
 		taskList.addTaskIfAbsent(task);
 
+		initTaskListeners();
+
 		// notify that a task is about to be activated
 		for (ITaskActivationListener listener : new ArrayList<ITaskActivationListener>(activationListeners)) {
 			try {
@@ -443,6 +497,8 @@ public class TaskActivityManager implements ITaskActivityManager {
 
 		if (task.isActive() && task == activeTask) {
 			// notify that a task is about to be deactivated
+			initTaskListeners();
+
 			for (ITaskActivationListener listener : new ArrayList<ITaskActivationListener>(activationListeners)) {
 				try {
 					listener.preTaskDeactivated(task);
