@@ -51,17 +51,16 @@ import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.util.SafeRunnable;
 import org.eclipse.mylyn.commons.core.StatusHandler;
+import org.eclipse.mylyn.commons.identity.core.IIdentityService;
 import org.eclipse.mylyn.commons.net.WebUtil;
-import org.eclipse.mylyn.context.core.ContextCore;
-import org.eclipse.mylyn.internal.commons.identity.IdentityModel;
-import org.eclipse.mylyn.internal.commons.identity.gravatar.GravatarConnector;
-import org.eclipse.mylyn.internal.commons.ui.TaskBarManager;
-import org.eclipse.mylyn.internal.context.core.ContextCorePlugin;
+import org.eclipse.mylyn.commons.notifications.core.NotificationEnvironment;
+import org.eclipse.mylyn.commons.notifications.feed.ServiceMessageManager;
+import org.eclipse.mylyn.commons.notifications.ui.AbstractUiNotification;
+import org.eclipse.mylyn.commons.ui.compatibility.CommonColors;
+import org.eclipse.mylyn.commons.ui.compatibility.CommonFonts;
+import org.eclipse.mylyn.commons.workbench.TaskBarManager;
 import org.eclipse.mylyn.internal.discovery.ui.DiscoveryUi;
 import org.eclipse.mylyn.internal.monitor.ui.MonitorUiPlugin;
-import org.eclipse.mylyn.internal.provisional.commons.ui.AbstractNotification;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonColors;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonFonts;
 import org.eclipse.mylyn.internal.tasks.core.AbstractSearchHandler;
 import org.eclipse.mylyn.internal.tasks.core.AbstractTask;
 import org.eclipse.mylyn.internal.tasks.core.IRepositoryModelListener;
@@ -83,8 +82,6 @@ import org.eclipse.mylyn.internal.tasks.core.externalization.ExternalizationMana
 import org.eclipse.mylyn.internal.tasks.core.externalization.IExternalizationParticipant;
 import org.eclipse.mylyn.internal.tasks.core.externalization.TaskListExternalizationParticipant;
 import org.eclipse.mylyn.internal.tasks.core.externalization.TaskListExternalizer;
-import org.eclipse.mylyn.internal.tasks.core.notifications.Environment;
-import org.eclipse.mylyn.internal.tasks.core.notifications.ServiceMessageManager;
 import org.eclipse.mylyn.internal.tasks.ui.actions.ActivateTaskDialogAction;
 import org.eclipse.mylyn.internal.tasks.ui.actions.NewTaskAction;
 import org.eclipse.mylyn.internal.tasks.ui.notifications.TaskListNotificationReminder;
@@ -96,11 +93,11 @@ import org.eclipse.mylyn.tasks.core.AbstractRepositoryConnector;
 import org.eclipse.mylyn.tasks.core.IRepositoryQuery;
 import org.eclipse.mylyn.tasks.core.ITask;
 import org.eclipse.mylyn.tasks.core.ITask.PriorityLevel;
-import org.eclipse.mylyn.tasks.core.ITaskActivationListener;
 import org.eclipse.mylyn.tasks.core.ITaskContainer;
 import org.eclipse.mylyn.tasks.core.RepositoryTemplate;
-import org.eclipse.mylyn.tasks.core.TaskActivationAdapter;
 import org.eclipse.mylyn.tasks.core.TaskRepository;
+import org.eclipse.mylyn.tasks.core.activity.AbstractTaskActivityMonitor;
+import org.eclipse.mylyn.tasks.core.context.AbstractTaskContextStore;
 import org.eclipse.mylyn.tasks.ui.AbstractRepositoryConnectorUi;
 import org.eclipse.mylyn.tasks.ui.AbstractTaskRepositoryLinkProvider;
 import org.eclipse.mylyn.tasks.ui.TasksUi;
@@ -118,6 +115,7 @@ import org.eclipse.ui.progress.IProgressService;
 import org.eclipse.ui.progress.UIJob;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceReference;
+import org.osgi.util.tracker.ServiceTracker;
 
 /**
  * Main entry point for the Tasks UI.
@@ -178,13 +176,13 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 
 	private ISaveParticipant saveParticipant;
 
-	private TaskEditorBloatMonitor taskEditorBloatManager;
-
 	private TaskJobFactory taskJobFactory;
 
 	// shared colors for all forms
 	private FormColors formColors;
 
+	private static AbstractTaskContextStore contextStore;
+
 	private final List<AbstractSearchHandler> searchHandlers = new ArrayList<AbstractSearchHandler>();
 
 	private static final boolean DEBUG_HTTPCLIENT = "true".equalsIgnoreCase(Platform.getDebugOption("org.eclipse.mylyn.tasks.ui/debug/httpclient")); //$NON-NLS-1$ //$NON-NLS-2$
@@ -254,25 +252,11 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 		EDITOR, INTERNAL_BROWSER, EXTERNAL_BROWSER;
 	}
 
-	private static ITaskActivationListener CONTEXT_TASK_ACTIVATION_LISTENER = new TaskActivationAdapter() {
-
-		@Override
-		public void taskActivated(final ITask task) {
-			ContextCore.getContextManager().activateContext(task.getHandleIdentifier());
-		}
-
-		@Override
-		public void taskDeactivated(final ITask task) {
-			ContextCore.getContextManager().deactivateContext(task.getHandleIdentifier());
-		}
-
-	};
-
 	private static ITaskListNotificationProvider REMINDER_NOTIFICATION_PROVIDER = new ITaskListNotificationProvider() {
 
-		public Set<AbstractNotification> getNotifications() {
+		public Set<AbstractUiNotification> getNotifications() {
 			Collection<AbstractTask> allTasks = TasksUiPlugin.getTaskList().getAllTasks();
-			Set<AbstractNotification> reminders = new HashSet<AbstractNotification>();
+			Set<AbstractUiNotification> reminders = new HashSet<AbstractUiNotification>();
 			for (AbstractTask task : allTasks) {
 				if (TasksUiPlugin.getTaskActivityManager().isPastReminder(task) && !task.isReminded()) {
 					reminders.add(new TaskListNotificationReminder(task));
@@ -368,7 +352,7 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 		}
 	};
 
-	private TaskActivityMonitor taskActivityMonitor;
+	private AbstractTaskActivityMonitor taskActivityMonitor;
 
 	private ServiceReference proxyServiceReference;
 
@@ -376,8 +360,6 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 
 	private static TaskListExternalizationParticipant taskListExternalizationParticipant;
 
-	private ActiveContextExternalizationParticipant activeContextExternalizationParticipant;
-
 	private final Set<IRepositoryModelListener> listeners = new HashSet<IRepositoryModelListener>();
 
 	private File activationHistoryFile;
@@ -465,19 +447,12 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 				if (repositoriesView != null) {
 					repositoriesView.getViewer().refresh();
 				}
-
-				taskEditorBloatManager = new TaskEditorBloatMonitor();
-				taskEditorBloatManager.install(PlatformUI.getWorkbench());
 			} catch (Throwable t) {
 				StatusHandler.log(new Status(IStatus.ERROR, TasksUiPlugin.ID_PLUGIN,
 						"Could not finish Tasks UI initialization", t)); //$NON-NLS-1$
 			} finally {
 				monitor.done();
 			}
-			activeContextExternalizationParticipant = new ActiveContextExternalizationParticipant(
-					externalizationManager);
-			externalizationManager.addParticipant(activeContextExternalizationParticipant);
-			activeContextExternalizationParticipant.registerListeners();
 			return new Status(IStatus.OK, TasksUiPlugin.ID_PLUGIN, IStatus.OK, "", null); //$NON-NLS-1$
 		}
 	}
@@ -615,10 +590,8 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 
 			taskJobFactory = new TaskJobFactory(taskList, taskDataManager, repositoryManager, repositoryModel);
 
-			taskActivityManager.addActivationListener(CONTEXT_TASK_ACTIVATION_LISTENER);
-
-			taskActivityMonitor = new TaskActivityMonitor(taskActivityManager, ContextCorePlugin.getContextManager());
-			taskActivityMonitor.start();
+			taskActivityMonitor = TasksUiExtensionReader.loadTaskActivityMonitor();
+			taskActivityMonitor.start(taskActivityManager);
 
 			saveParticipant = new ISaveParticipant() {
 
@@ -639,12 +612,6 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 			};
 			ResourcesPlugin.getWorkspace().addSaveParticipant(this, saveParticipant);
 
-			ActivityExternalizationParticipant ACTIVITY_EXTERNALIZTAION_PARTICIPANT = new ActivityExternalizationParticipant(
-					externalizationManager);
-			externalizationManager.addParticipant(ACTIVITY_EXTERNALIZTAION_PARTICIPANT);
-			taskActivityManager.addActivityListener(ACTIVITY_EXTERNALIZTAION_PARTICIPANT);
-			taskActivityMonitor.setExternalizationParticipant(ACTIVITY_EXTERNALIZTAION_PARTICIPANT);
-
 			// initialize externalization for task activation history
 			IPath stateLocation = Platform.getStateLocation(getBundle());
 			activationHistoryFile = stateLocation.append("TaskActivationHistory.xml").toFile(); //$NON-NLS-1$
@@ -668,7 +635,7 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 			Long checktime = getPreferenceStore().getLong(ITasksUiPreferenceConstants.LAST_SERVICE_MESSAGE_CHECKTIME);
 
 			serviceMessageManager = new ServiceMessageManager(serviceMessageUrl, lastMod, etag, checktime,
-					new Environment() {
+					new NotificationEnvironment() {
 						private Set<String> installedFeatures;
 
 						@Override
@@ -802,6 +769,10 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 				}
 				context.ungetService(proxyServiceReference);
 			}
+			if (identityServiceTracker != null) {
+				identityServiceTracker.close();
+				identityServiceTracker = null;
+			}
 
 			if (PlatformUI.isWorkbenchRunning()) {
 				getPreferenceStore().removePropertyChangeListener(taskListNotificationManager);
@@ -814,7 +785,6 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 //							PREFERENCE_LISTENER);
 //				}
 				serviceMessageManager.stop();
-				taskEditorBloatManager.dispose(PlatformUI.getWorkbench());
 				INSTANCE = null;
 			}
 		} catch (Exception e) {
@@ -893,17 +863,22 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 	 */
 	@SuppressWarnings("restriction")
 	public void initializeDataSources() {
+		// ensure that context directory exists
+		File storeFile = new File(getDataDirectory(), ITasksCoreConstants.CONTEXTS_DIRECTORY);
+		if (!storeFile.exists()) {
+			storeFile.mkdirs();
+		}
+
 		taskDataManager.setDataPath(getDataDirectory());
 		externalizationManager.setRootFolderPath(getDataDirectory());
-		ContextCorePlugin.getContextStore().setContextDirectory(getContextStoreDir());
+		getContextStore().setDirectory(new File(getDataDirectory(), "tasks")); //$NON-NLS-1$
 
 		externalizationManager.load();
 		// TODO: Move management of template repositories to TaskRepositoryManager
 		loadTemplateRepositories();
 
 		taskActivityManager.clear();
-		ContextCorePlugin.getContextManager().loadActivityMetaContext();
-		taskActivityMonitor.reloadActivityTime();
+		taskActivityMonitor.loadActivityTime();
 		taskActivityManager.reloadPlanningData();
 
 		if (!activationHistoryFile.exists() && taskActivityManager.getTaskActivationHistory().getSize() == 0) {
@@ -945,14 +920,6 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 		}
 	}
 
-	private File getContextStoreDir() {
-		File storeFile = new File(getDataDirectory(), ITasksCoreConstants.CONTEXTS_DIRECTORY);
-		if (!storeFile.exists()) {
-			storeFile.mkdirs();
-		}
-		return storeFile;
-	}
-
 	@SuppressWarnings("deprecation")
 	private void initializePreferences(IPreferenceStore store) {
 		store.setDefault(ITasksUiPreferenceConstants.PREF_DATA_DIR, getDefaultDataDirectory());
@@ -1033,7 +1000,7 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 
 	private final Map<String, List<IDynamicSubMenuContributor>> menuContributors = new HashMap<String, List<IDynamicSubMenuContributor>>();
 
-	private IdentityModel identityModel;
+	private ServiceTracker identityServiceTracker;
 
 	public Map<String, List<IDynamicSubMenuContributor>> getDynamicMenuMap() {
 		return menuContributors;
@@ -1304,7 +1271,7 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 		return externalizationManager;
 	}
 
-	public static TaskActivityMonitor getTaskActivityMonitor() {
+	public static AbstractTaskActivityMonitor getTaskActivityMonitor() {
 		return INSTANCE.taskActivityMonitor;
 	}
 
@@ -1381,8 +1348,7 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 		try {
 			taskListNotificationManager.addNotificationProvider(REMINDER_NOTIFICATION_PROVIDER);
 //				taskListNotificationManager.addNotificationProvider(INCOMING_NOTIFICATION_PROVIDER);
-			TaskListNotifier taskListNotifier = new TaskListNotifier(getRepositoryModel(), getTaskDataManager(),
-					getSynchronizationManger());
+			TaskListNotifier taskListNotifier = new TaskListNotifier(getTaskDataManager(), getSynchronizationManger());
 			getTaskDataManager().addListener(taskListNotifier);
 			taskListNotificationManager.addNotificationProvider(taskListNotifier);
 			taskListNotificationManager.startNotification(NOTIFICATION_DELAY);
@@ -1413,11 +1379,20 @@ public class TasksUiPlugin extends AbstractUIPlugin {
 		return synchronizationManger;
 	}
 
-	public IdentityModel getIdentityModel() {
-		if (identityModel == null) {
-			identityModel = new IdentityModel(new File(getDataDirectory(), "cache"));
-			identityModel.addConnector(new GravatarConnector());
+	public IIdentityService getIdentityService() {
+		if (identityServiceTracker == null) {
+			identityServiceTracker = new ServiceTracker(getBundle().getBundleContext(),
+					IIdentityService.class.getName(), null);
+			identityServiceTracker.open();
 		}
-		return identityModel;
+		return (IIdentityService) identityServiceTracker.getService();
 	}
+
+	public static synchronized AbstractTaskContextStore getContextStore() {
+		if (contextStore == null) {
+			contextStore = TasksUiExtensionReader.loadTaskContextStore();
+		}
+		return contextStore;
+	}
+
 }
