@@ -46,7 +46,7 @@ import org.eclipse.jface.util.PropertyChangeEvent;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.window.Window;
 import org.eclipse.jface.wizard.WizardDialog;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonColors;
+import org.eclipse.mylyn.commons.ui.compatibility.CommonColors;
 import org.eclipse.mylyn.internal.tasks.core.AbstractTask;
 import org.eclipse.mylyn.internal.tasks.core.AbstractTaskContainer;
 import org.eclipse.mylyn.internal.tasks.core.TaskActivationHistory;
@@ -429,7 +429,11 @@ public class TaskSelectionDialog extends FilteredItemsSelectionDialog {
 	private final TaskActivationHistory taskActivationHistory;
 
 	public TaskSelectionDialog(Shell parent) {
-		super(parent);
+		this(parent, false);
+	}
+	
+	public TaskSelectionDialog(Shell parent, boolean multi) {
+		super(parent, multi);
 		this.taskActivationHistory = TasksUiPlugin.getTaskActivityManager().getTaskActivationHistory();
 		this.history = new LinkedHashSet<AbstractTask>(taskActivationHistory.getPreviousTasks());
 		this.itemsComparator = new TaskHistoryItemsComparator(new ArrayList<AbstractTask>(history));
