@@ -18,16 +18,17 @@ import org.eclipse.core.runtime.Assert;
 import org.eclipse.jface.action.ToolBarManager;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.layout.GridDataFactory;
+import org.eclipse.jface.layout.GridLayoutFactory;
 import org.eclipse.jface.text.ITextListener;
 import org.eclipse.jface.text.TextEvent;
 import org.eclipse.jface.util.IPropertyChangeListener;
 import org.eclipse.mylyn.commons.core.DateUtil;
+import org.eclipse.mylyn.commons.ui.CommonImages;
+import org.eclipse.mylyn.commons.ui.CommonUiUtil;
+import org.eclipse.mylyn.commons.ui.PlatformUiUtil;
+import org.eclipse.mylyn.commons.workbench.editors.CommonTextSupport;
+import org.eclipse.mylyn.commons.workbench.forms.DatePicker;
 import org.eclipse.mylyn.internal.monitor.ui.MonitorUiPlugin;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonImages;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonTextSupport;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonUiUtil;
-import org.eclipse.mylyn.internal.provisional.commons.ui.DatePicker;
-import org.eclipse.mylyn.internal.provisional.commons.ui.PlatformUiUtil;
 import org.eclipse.mylyn.internal.tasks.core.AbstractTask;
 import org.eclipse.mylyn.internal.tasks.core.DateRange;
 import org.eclipse.mylyn.internal.tasks.core.DayDateRange;
@@ -80,6 +81,7 @@ import org.eclipse.ui.forms.widgets.Section;
 
 /**
  * @author Shawn Minto
+ * @author Sam Davis
  */
 public class PlanningPart extends AbstractLocalEditorPart {
 
@@ -202,6 +204,8 @@ public class PlanningPart extends AbstractLocalEditorPart {
 
 	private Label scheduledLabel;
 
+	private Composite layoutControl;
+
 	public PlanningPart(int sectionStyle) {
 		super(sectionStyle, Messages.PersonalPart_Personal_Planning);
 		this.activeTimeEnabled = true;
@@ -299,24 +303,29 @@ public class PlanningPart extends AbstractLocalEditorPart {
 
 	private void expandSection(FormToolkit toolkit, Section section) {
 		sectionClient = toolkit.createComposite(section);
+		GridLayoutFactory.fillDefaults().applyTo(sectionClient);
+
+		// create nested composite with GridData to enable resizing behavior of maximize action
+		layoutControl = toolkit.createComposite(sectionClient);
+		GridDataFactory.fillDefaults().grab(true, true).applyTo(layoutControl);
 		GridLayout layout = EditorUtil.createSectionClientLayout();
 		layout.numColumns = (needsDueDate) ? 6 : 4;
-		sectionClient.setLayout(layout);
+		layoutControl.setLayout(layout);
 
-		createScheduledDatePicker(toolkit, sectionClient);
+		createScheduledDatePicker(toolkit, layoutControl);
 
 		// disable due date picker if it's a repository due date
 		if (needsDueDate) {
-			createDueDatePicker(toolkit, sectionClient);
+			createDueDatePicker(toolkit, layoutControl);
 		}
 
-		createEstimatedTime(toolkit, sectionClient);
+		createEstimatedTime(toolkit, layoutControl);
 
 		if (needsNotes()) {
-			createNotesArea(toolkit, sectionClient, layout.numColumns);
+			createNotesArea(toolkit, layoutControl, layout.numColumns);
 		}
 
-		createActiveTime(toolkit, sectionClient, layout.numColumns);
+		createActiveTime(toolkit, layoutControl, layout.numColumns);
 
 		toolkit.paintBordersFor(sectionClient);
 		section.setClient(sectionClient);
@@ -461,7 +470,7 @@ public class PlanningPart extends AbstractLocalEditorPart {
 	}
 
 	private void updateActiveTime() {
-		boolean show = MonitorUiPlugin.getDefault().isActivityTrackingEnabled() && isActiveTimeEnabled();
+		boolean show = TasksUiInternal.isActivityTrackingEnabled() && isActiveTimeEnabled();
 		long elapsedTime = TasksUiInternal.getActiveTime(getTask());
 		boolean visible = activeTimeComposite != null && activeTimeComposite.isVisible();
 		if (show && (elapsedTime > 0 || getTask().isActive())) {
@@ -744,4 +753,8 @@ public class PlanningPart extends AbstractLocalEditorPart {
 		return noteEditor;
 	}
 
+	public Control getLayoutControl() {
+		return layoutControl;
+	}
+
 }
