@@ -26,9 +26,9 @@ import org.eclipse.jface.layout.GridDataFactory;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.StructuredSelection;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonFormUtil;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonImages;
-import org.eclipse.mylyn.internal.provisional.commons.ui.SelectionProviderAdapter;
+import org.eclipse.mylyn.commons.ui.CommonImages;
+import org.eclipse.mylyn.commons.ui.SelectionProviderAdapter;
+import org.eclipse.mylyn.commons.workbench.forms.CommonFormUtil;
 import org.eclipse.mylyn.internal.tasks.core.TaskComment;
 import org.eclipse.mylyn.internal.tasks.ui.actions.CommentActionGroup;
 import org.eclipse.mylyn.internal.tasks.ui.editors.CommentGroupStrategy.CommentGroup;
@@ -39,14 +39,11 @@ import org.eclipse.mylyn.tasks.core.data.TaskDataModel;
 import org.eclipse.mylyn.tasks.ui.TasksUiImages;
 import org.eclipse.mylyn.tasks.ui.editors.AbstractAttributeEditor;
 import org.eclipse.mylyn.tasks.ui.editors.AbstractTaskEditorPart;
-import org.eclipse.osgi.util.NLS;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.MouseAdapter;
 import org.eclipse.swt.events.MouseEvent;
 import org.eclipse.swt.events.PaintEvent;
 import org.eclipse.swt.events.PaintListener;
-import org.eclipse.swt.graphics.Font;
-import org.eclipse.swt.graphics.FontData;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -296,7 +293,7 @@ public class TaskEditorCommentPart extends AbstractTaskEditorPart {
 
 	}
 
-	private class CommentViewer {
+	protected class CommentViewer {
 
 		private Composite buttonComposite;
 
@@ -372,6 +369,10 @@ public class TaskEditorCommentPart extends AbstractTaskEditorPart {
 				}
 			});
 
+			ToolBarManager toolBarManagerTitle = new ToolBarManager(SWT.FLAT);
+			addActionsToToolbarTitle(toolBarManagerTitle, taskComment, this);
+			toolBarManagerTitle.createControl(titleComposite);
+
 			// only visible when section is expanded
 			final Composite buttonComposite = toolkit.createComposite(titleComposite);
 			RowLayout buttonCompLayout = new RowLayout();
@@ -381,11 +382,9 @@ public class TaskEditorCommentPart extends AbstractTaskEditorPart {
 			buttonComposite.setBackground(null);
 			buttonComposite.setVisible(commentComposite.isExpanded());
 
-			ToolBarManager toolBarManager = new ToolBarManager(SWT.FLAT);
-			ReplyToCommentAction replyAction = new ReplyToCommentAction(this, taskComment);
-			replyAction.setImageDescriptor(TasksUiImages.COMMENT_REPLY_SMALL);
-			toolBarManager.add(replyAction);
-			toolBarManager.createControl(buttonComposite);
+			ToolBarManager toolBarManagerButton = new ToolBarManager(SWT.FLAT);
+			addActionsToToolbarButton(toolBarManagerButton, taskComment, this);
+			toolBarManagerButton.createControl(buttonComposite);
 
 			return buttonComposite;
 		}
@@ -420,30 +419,8 @@ public class TaskEditorCommentPart extends AbstractTaskEditorPart {
 				sb.append(", "); //$NON-NLS-1$
 				sb.append(EditorUtil.formatDateTime(taskComment.getCreationDate()));
 			}
-//			We need the CommentID for change the value of private
-//			this is only for an test included
-//			Maybe we need this for bug# 284026
-//			TaskAttribute commentID = taskComment.getTaskAttribute().getAttribute("commentid");
-//			if (commentID != null) {
-//				String value = commentID.getValue();
-//				sb.append(" (ID " + value + ")");
-//			}
-			if (taskComment.getIsPrivate() != null && taskComment.getIsPrivate()) {
-				if (privateFont == null) {
-					Font a = formHyperlink.getFont();
-					FontData[] fd = a.getFontData();
-					for (FontData fontData : fd) {
-						fontData.setStyle(SWT.ITALIC | SWT.BOLD);
-					}
-					privateFont = new Font(formHyperlink.getDisplay(), fd);
-				}
-				formHyperlink.setFont(privateFont);
-				toolTipText = NLS.bind(Messages.TaskEditorCommentPart_Privat_Comment_ToolTip_Text, toolTipText);
-			} else {
-				formHyperlink.setFont(commentComposite.getFont());
-			}
+			formHyperlink.setFont(commentComposite.getFont());
 			formHyperlink.setToolTipText(toolTipText);
-
 			formHyperlink.setText(sb.toString());
 			formHyperlink.setEnabled(true);
 			formHyperlink.setUnderlined(false);
@@ -575,8 +552,6 @@ public class TaskEditorCommentPart extends AbstractTaskEditorPart {
 
 	private CommentActionGroup actionGroup;
 
-	private Font privateFont;
-
 	private boolean suppressExpandViewers;
 
 	public TaskEditorCommentPart() {
@@ -589,6 +564,17 @@ public class TaskEditorCommentPart extends AbstractTaskEditorPart {
 		setPartName(Messages.TaskEditorCommentPart_Comments);
 	}
 
+	protected void addActionsToToolbarButton(ToolBarManager toolBarManager, final TaskComment taskComment,
+			CommentViewer commentViewer) {
+		ReplyToCommentAction replyAction = new ReplyToCommentAction(commentViewer, taskComment);
+		replyAction.setImageDescriptor(TasksUiImages.COMMENT_REPLY_SMALL);
+		toolBarManager.add(replyAction);
+	}
+
+	protected void addActionsToToolbarTitle(ToolBarManager toolBarManager, final TaskComment taskComment,
+			CommentViewer commentViewer) {
+	}
+
 	private void collapseAllComments() {
 		try {
 			getTaskEditorPage().setReflow(false);
@@ -701,9 +687,6 @@ public class TaskEditorCommentPart extends AbstractTaskEditorPart {
 		if (actionGroup != null) {
 			actionGroup.dispose();
 		}
-		if (privateFont != null) {
-			privateFont.dispose();
-		}
 	}
 
 	private void expandAllComments(boolean expandViewers) {
