@@ -57,14 +57,13 @@ import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.jface.viewers.TreeViewer;
 import org.eclipse.jface.window.Window;
 import org.eclipse.jface.wizard.IWizard;
-import org.eclipse.jface.wizard.WizardDialog;
 import org.eclipse.mylyn.commons.core.CoreUtil;
 import org.eclipse.mylyn.commons.core.StatusHandler;
-import org.eclipse.mylyn.commons.identity.Account;
+import org.eclipse.mylyn.commons.identity.core.Account;
+import org.eclipse.mylyn.commons.ui.CommonImages;
+import org.eclipse.mylyn.commons.ui.CommonUiUtil;
+import org.eclipse.mylyn.commons.workbench.WorkbenchUtil;
 import org.eclipse.mylyn.internal.monitor.ui.MonitorUiPlugin;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonImages;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonUiUtil;
-import org.eclipse.mylyn.internal.provisional.commons.ui.WorkbenchUtil;
 import org.eclipse.mylyn.internal.tasks.core.AbstractTask;
 import org.eclipse.mylyn.internal.tasks.core.AbstractTaskCategory;
 import org.eclipse.mylyn.internal.tasks.core.AbstractTaskContainer;
@@ -88,6 +87,7 @@ import org.eclipse.mylyn.internal.tasks.ui.views.TaskListView;
 import org.eclipse.mylyn.internal.tasks.ui.wizards.MultiRepositoryAwareWizard;
 import org.eclipse.mylyn.internal.tasks.ui.wizards.NewAttachmentWizardDialog;
 import org.eclipse.mylyn.internal.tasks.ui.wizards.NewTaskWizardInternal;
+import org.eclipse.mylyn.internal.tasks.ui.wizards.QueryWizardDialog;
 import org.eclipse.mylyn.internal.tasks.ui.wizards.TaskAttachmentWizard;
 import org.eclipse.mylyn.tasks.core.AbstractRepositoryConnector;
 import org.eclipse.mylyn.tasks.core.IRepositoryElement;
@@ -149,6 +149,8 @@ public class TasksUiInternal {
 
 	private static SynchronizationScheduler synchronizationScheduler = new SynchronizationScheduler();
 
+	private static final TaskDropHandler taskDropHandler = new TaskDropHandler();
+
 	// TODO e3.5 replace by SWT.SHEET
 	public static final int SWT_SHEET = 1 << 28;
 
@@ -170,8 +172,10 @@ public class TasksUiInternal {
 			IHandlerService handlerService = (IHandlerService) PlatformUI.getWorkbench().getService(
 					IHandlerService.class);
 			EvaluationContext evaluationContext = createDiscoveryWizardEvaluationContext(handlerService);
-			// update enabled state in case something has changed (ProxyHandler caches state)
-			discoveryWizardCommand.setEnabled(evaluationContext);
+			if (!discoveryWizardCommand.isEnabled()) {
+				// update enabled state in case something has changed (ProxyHandler caches state)
+				discoveryWizardCommand.setEnabled(evaluationContext);
+			}
 		}
 		return discoveryWizardCommand;
 	}
@@ -546,30 +550,29 @@ public class TasksUiInternal {
 			return;
 		}
 
-		if (status.getCode() == RepositoryStatus.ERROR_INTERNAL) {
-			StatusHandler.fail(status);
+		if (status instanceof RepositoryStatus && ((RepositoryStatus) status).isHtmlMessage()) {
+			WebBrowserDialog.openAcceptAgreement(shell, title, status.getMessage(),
+					((RepositoryStatus) status).getHtmlMessage());
 		} else {
-			if (status instanceof RepositoryStatus && ((RepositoryStatus) status).isHtmlMessage()) {
-				WebBrowserDialog.openAcceptAgreement(shell, title, status.getMessage(),
-						((RepositoryStatus) status).getHtmlMessage());
-			} else {
-				String message = status.getMessage();
-				if (showLinkToErrorLog) {
-					message += "\n\n" + Messages.TasksUiInternal_See_error_log_for_details; //$NON-NLS-1$
-				}
-				switch (status.getSeverity()) {
-				case IStatus.CANCEL:
-				case IStatus.INFO:
-					createDialog(shell, title, message, MessageDialog.INFORMATION).open();
-					break;
-				case IStatus.WARNING:
-					createDialog(shell, title, message, MessageDialog.WARNING).open();
-					break;
-				case IStatus.ERROR:
-				default:
-					createDialog(shell, title, message, MessageDialog.ERROR).open();
-					break;
-				}
+			String message = status.getMessage();
+			if (message == null || message.trim().length() == 0) {
+				message = Messages.TasksUiInternal_An_unknown_error_occurred;
+			}
+			if (showLinkToErrorLog) {
+				message += "\n\n" + Messages.TasksUiInternal_See_error_log_for_details; //$NON-NLS-1$
+			}
+			switch (status.getSeverity()) {
+			case IStatus.CANCEL:
+			case IStatus.INFO:
+				createDialog(shell, title, message, MessageDialog.INFORMATION).open();
+				break;
+			case IStatus.WARNING:
+				createDialog(shell, title, message, MessageDialog.WARNING).open();
+				break;
+			case IStatus.ERROR:
+			default:
+				createDialog(shell, title, message, MessageDialog.ERROR).open();
+				break;
 			}
 		}
 	}
@@ -699,7 +702,7 @@ public class TasksUiInternal {
 
 			Shell shell = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell();
 			if (wizard != null && shell != null && !shell.isDisposed()) {
-				WizardDialog dialog = new WizardDialog(shell, wizard) {
+				QueryWizardDialog dialog = new QueryWizardDialog(shell, wizard) {
 					private static final String DIALOG_SETTINGS = "EditQueryWizardWizard"; //$NON-NLS-1$
 
 					@Override
@@ -1281,7 +1284,7 @@ public class TasksUiInternal {
 	}
 
 	public static long getActiveTime(ITask task) {
-		if (MonitorUiPlugin.getDefault().isActivityTrackingEnabled()) {
+		if (TasksUiInternal.isActivityTrackingEnabled()) {
 			return TasksUiPlugin.getTaskActivityManager().getElapsedTime(task);
 		}
 		return 0;
@@ -1439,4 +1442,13 @@ public class TasksUiInternal {
 		return account.kind(repository.getConnectorKind()).url(repository.getRepositoryUrl());
 	}
 
+	public static boolean isActivityTrackingEnabled() {
+		return TasksUiPlugin.getTaskActivityMonitor().isEnabled()
+				&& MonitorUiPlugin.getDefault().isActivityTrackingEnabled();
+	}
+
+	public static TaskDropHandler getTaskDropHandler() {
+		return taskDropHandler;
+	}
+
 }
