@@ -8,6 +8,7 @@
  * Contributors:
  *     Tasktop Technologies - initial API and implementation
  *     Kevin Barnes, IBM Corporation - fix for bug 277974
+ *     Robert Munteanu - fix for bug 350771
  *******************************************************************************/
 
 package org.eclipse.mylyn.internal.tasks.ui.views;
@@ -21,13 +22,12 @@ import org.eclipse.core.runtime.IAdaptable;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.jface.layout.GridDataFactory;
 import org.eclipse.mylyn.commons.core.DateUtil;
-import org.eclipse.mylyn.internal.monitor.ui.MonitorUiPlugin;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonFonts;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonImages;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonUiUtil;
-import org.eclipse.mylyn.internal.provisional.commons.ui.GradientToolTip;
-import org.eclipse.mylyn.internal.provisional.commons.ui.PlatformUiUtil;
-import org.eclipse.mylyn.internal.provisional.commons.ui.ScalingHyperlink;
+import org.eclipse.mylyn.commons.ui.CommonImages;
+import org.eclipse.mylyn.commons.ui.CommonUiUtil;
+import org.eclipse.mylyn.commons.ui.GradientToolTip;
+import org.eclipse.mylyn.commons.ui.PlatformUiUtil;
+import org.eclipse.mylyn.commons.ui.compatibility.CommonFonts;
+import org.eclipse.mylyn.commons.workbench.forms.ScalingHyperlink;
 import org.eclipse.mylyn.internal.tasks.core.AbstractTask;
 import org.eclipse.mylyn.internal.tasks.core.AbstractTaskContainer;
 import org.eclipse.mylyn.internal.tasks.core.DateRange;
@@ -246,7 +246,7 @@ public class TaskListToolTip extends GradientToolTip {
 	private void appendEstimateAndActive(StringBuilder sb, int estimateTotal, long activeTotal) {
 		sb.append(NLS.bind(Messages.TaskListToolTip_Estimate, estimateTotal));
 		sb.append("\n"); //$NON-NLS-1$
-		if (MonitorUiPlugin.getDefault().isActivityTrackingEnabled()) {
+		if (TasksUiInternal.isActivityTrackingEnabled()) {
 			sb.append(NLS.bind(Messages.TaskListToolTip_Active_X, DateUtil.getFormattedDurationShort(activeTotal)));
 			sb.append("\n"); //$NON-NLS-1$
 		}
@@ -297,11 +297,11 @@ public class TaskListToolTip extends GradientToolTip {
 			ITask task = (ITask) element;
 			if (task.getSynchronizationState().isIncoming()) {
 				String text = null;
-				TaskListNotifier notifier = new TaskListNotifier(TasksUiPlugin.getRepositoryModel(),
-						TasksUiPlugin.getTaskDataManager(), TasksUiPlugin.getDefault().getSynchronizationManger());
+				TaskListNotifier notifier = new TaskListNotifier(TasksUiPlugin.getTaskDataManager(),
+						TasksUiPlugin.getDefault().getSynchronizationManger());
 				TaskDataDiff diff = notifier.getDiff(task);
 				if (diff != null && diff.hasChanged()) {
-					text = TaskDiffUtil.toString(diff, MAX_TEXT_WIDTH, false);
+					text = TaskDiffUtil.toString(diff, MAX_TEXT_WIDTH, true);
 				}
 				if (text != null && text.length() > 0) {
 					return text;
