@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2010 Tasktop Technologies and others.
+ * Copyright (c) 2004, 2011 Tasktop Technologies and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -59,12 +59,12 @@ import org.eclipse.jface.viewers.TreePath;
 import org.eclipse.jface.viewers.TreeSelection;
 import org.eclipse.jface.viewers.TreeViewer;
 import org.eclipse.mylyn.commons.core.StatusHandler;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonImages;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonThemes;
-import org.eclipse.mylyn.internal.provisional.commons.ui.DelayedRefreshJob;
-import org.eclipse.mylyn.internal.provisional.commons.ui.GradientDrawer;
-import org.eclipse.mylyn.internal.provisional.commons.ui.PlatformUiUtil;
-import org.eclipse.mylyn.internal.provisional.commons.ui.SubstringPatternFilter;
+import org.eclipse.mylyn.commons.ui.CommonImages;
+import org.eclipse.mylyn.commons.ui.PlatformUiUtil;
+import org.eclipse.mylyn.commons.ui.compatibility.CommonThemes;
+import org.eclipse.mylyn.commons.workbench.DelayedRefreshJob;
+import org.eclipse.mylyn.commons.workbench.GradientDrawer;
+import org.eclipse.mylyn.internal.commons.notifications.feed.ServiceMessage;
 import org.eclipse.mylyn.internal.tasks.core.AbstractTask;
 import org.eclipse.mylyn.internal.tasks.core.AbstractTaskContainer;
 import org.eclipse.mylyn.internal.tasks.core.ITaskListChangeListener;
@@ -73,7 +73,6 @@ import org.eclipse.mylyn.internal.tasks.core.TaskContainerDelta;
 import org.eclipse.mylyn.internal.tasks.core.UncategorizedTaskContainer;
 import org.eclipse.mylyn.internal.tasks.core.UnmatchedTaskContainer;
 import org.eclipse.mylyn.internal.tasks.core.UnsubmittedTaskContainer;
-import org.eclipse.mylyn.internal.tasks.core.notifications.ServiceMessage;
 import org.eclipse.mylyn.internal.tasks.ui.AbstractTaskListFilter;
 import org.eclipse.mylyn.internal.tasks.ui.CategorizedPresentation;
 import org.eclipse.mylyn.internal.tasks.ui.ITasksUiPreferenceConstants;
@@ -100,6 +99,8 @@ import org.eclipse.mylyn.internal.tasks.ui.actions.TaskListSortAction;
 import org.eclipse.mylyn.internal.tasks.ui.actions.TaskListViewActionGroup;
 import org.eclipse.mylyn.internal.tasks.ui.editors.TaskListChangeAdapter;
 import org.eclipse.mylyn.internal.tasks.ui.notifications.TaskListServiceMessageControl;
+import org.eclipse.mylyn.internal.tasks.ui.search.AbstractSearchHandler;
+import org.eclipse.mylyn.internal.tasks.ui.search.SearchUtil;
 import org.eclipse.mylyn.internal.tasks.ui.util.SortCriterion;
 import org.eclipse.mylyn.internal.tasks.ui.util.SortCriterion.SortKey;
 import org.eclipse.mylyn.internal.tasks.ui.util.TaskDragSourceListener;
@@ -189,6 +190,7 @@ import org.eclipse.ui.themes.IThemeManager;
  * @author Mik Kersten
  * @author Ken Sueda
  * @author Eugene Kuleshov
+ * @author David Green
  */
 public class TaskListView extends ViewPart implements IPropertyChangeListener, IShowInTarget {
 
@@ -352,7 +354,7 @@ public class TaskListView extends ViewPart implements IPropertyChangeListener, I
 
 	private TaskListFilteredTree filteredTree;
 
-	private org.eclipse.mylyn.internal.provisional.commons.ui.SelectionProviderAdapter selectionProvider;
+	private org.eclipse.mylyn.commons.ui.SelectionProviderAdapter selectionProvider;
 
 	private DrillDownAdapter drillDownAdapter;
 
@@ -620,6 +622,9 @@ public class TaskListView extends ViewPart implements IPropertyChangeListener, I
 		if (editorListener != null) {
 			getSite().getPage().removePartListener(editorListener);
 		}
+		if (searchHandler != null) {
+			searchHandler.dispose();
+		}
 	}
 
 	private void updateDescription() {
@@ -792,14 +797,16 @@ public class TaskListView extends ViewPart implements IPropertyChangeListener, I
 			progress.showBusyForFamily(ITasksCoreConstants.JOB_FAMILY_SYNCHRONIZATION);
 		}
 
-		this.selectionProvider = new org.eclipse.mylyn.internal.provisional.commons.ui.SelectionProviderAdapter();
+		this.selectionProvider = new org.eclipse.mylyn.commons.ui.SelectionProviderAdapter();
 		getSite().setSelectionProvider(selectionProvider);
 
 		themeManager = getSite().getWorkbenchWindow().getWorkbench().getThemeManager();
 		themeManager.addPropertyChangeListener(THEME_CHANGE_LISTENER);
 
+		searchHandler = SearchUtil.createSearchHandler();
+
 		filteredTree = new TaskListFilteredTree(body, SWT.MULTI | SWT.VERTICAL | /* SWT.H_SCROLL | */SWT.V_SCROLL
-				| SWT.NO_SCROLL | SWT.FULL_SELECTION, new SubstringPatternFilter(), getViewSite().getWorkbenchWindow());
+				| SWT.NO_SCROLL | SWT.FULL_SELECTION, searchHandler, getViewSite().getWorkbenchWindow());
 
 		// need to do initialize tooltip early for native tooltip disablement to take effect
 		taskListToolTip = new TaskListToolTip(getViewer().getControl());
@@ -1008,7 +1015,7 @@ public class TaskListView extends ViewPart implements IPropertyChangeListener, I
 				.getString(ITasksUiPreferenceConstants.LAST_SERVICE_MESSAGE_ID);
 
 		if (showMessage && lastClosedId.equals("")) { //$NON-NLS-1$
-			ServiceMessage message = new ServiceMessage();
+			ServiceMessage message = new ServiceMessage("welcome"); //$NON-NLS-1$
 			message.setDescription(Messages.TaskListView_Welcome_Message);
 			message.setTitle(Messages.TaskListView_Welcome_Message_Title);
 			message.setImage(Dialog.DLG_IMG_MESSAGE_INFO);
@@ -1385,6 +1392,8 @@ public class TaskListView extends ViewPart implements IPropertyChangeListener, I
 
 	private boolean itemNotFoundExceptionLogged;
 
+	private AbstractSearchHandler searchHandler;
+
 	public void setInRenameAction(boolean b) {
 		isInRenameAction = b;
 	}
@@ -1593,7 +1602,7 @@ public class TaskListView extends ViewPart implements IPropertyChangeListener, I
 				manager.prependToGroup(ID_SEPARATOR_CONTEXT, filterCompleteTask);
 			}
 			updateFilterEnablement();
-			manager.update(false);
+			getViewSite().getActionBars().updateActionBars();
 		} finally {
 			if (toolBarManager != null) {
 				toolBarManager.getControl().setRedraw(true);
