@@ -20,7 +20,9 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
 
+import org.apache.commons.httpclient.URI;
 import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.IAdaptable;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.OperationCanceledException;
@@ -35,9 +37,10 @@ import org.eclipse.jface.wizard.IWizardContainer;
 import org.eclipse.mylyn.commons.core.StatusHandler;
 import org.eclipse.mylyn.commons.net.AuthenticationCredentials;
 import org.eclipse.mylyn.commons.net.AuthenticationType;
-import org.eclipse.mylyn.internal.provisional.commons.ui.CommonImages;
-import org.eclipse.mylyn.internal.provisional.commons.ui.WorkbenchUtil;
-import org.eclipse.mylyn.internal.provisional.commons.ui.dialogs.ValidatableWizardDialog;
+import org.eclipse.mylyn.commons.ui.CommonImages;
+import org.eclipse.mylyn.commons.ui.dialogs.IValidatable;
+import org.eclipse.mylyn.commons.ui.dialogs.ValidatableWizardDialog;
+import org.eclipse.mylyn.commons.workbench.browser.BrowserUtil;
 import org.eclipse.mylyn.internal.tasks.core.IRepositoryConstants;
 import org.eclipse.mylyn.internal.tasks.core.RepositoryTemplateManager;
 import org.eclipse.mylyn.internal.tasks.core.TaskRepositoryManager;
@@ -72,6 +75,7 @@ import org.eclipse.ui.forms.events.IHyperlinkListener;
 import org.eclipse.ui.forms.widgets.ExpandableComposite;
 import org.eclipse.ui.forms.widgets.FormToolkit;
 import org.eclipse.ui.forms.widgets.Hyperlink;
+import org.eclipse.ui.statushandlers.StatusManager;
 
 /**
  * Extend to provide custom repository settings. This page is typically invoked by the user requesting properties via
@@ -85,7 +89,8 @@ import org.eclipse.ui.forms.widgets.Hyperlink;
  * @author Helen Bershadskaya
  * @since 2.0
  */
-public abstract class AbstractRepositorySettingsPage extends AbstractTaskRepositoryPage implements ITaskRepositoryPage {
+public abstract class AbstractRepositorySettingsPage extends AbstractTaskRepositoryPage implements ITaskRepositoryPage,
+		IAdaptable {
 
 	protected static final String PREFS_PAGE_ID_NET_PROXY = "org.eclipse.ui.net.NetPreferences"; //$NON-NLS-1$
 
@@ -170,6 +175,8 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 	private boolean needsValidation;
 
+	private boolean needsValidateOnFinish;
+
 	private boolean needsAdvanced;
 
 	protected Composite compositeContainer;
@@ -225,6 +232,10 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 	private Button disconnectedButton;
 
+	private Button validateOnFinishButton;
+
+	private boolean isValid;
+
 	/**
 	 * @since 3.0
 	 */
@@ -238,6 +249,7 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 		setNeedsProxy(true);
 		setNeedsValidation(true);
 		setNeedsAdvanced(true);
+		setNeedsValidateOnFinish(false);
 	}
 
 	/**
@@ -274,7 +286,11 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 		createSettingControls(compositeContainer);
 		createValidationControls(compositeContainer);
-
+		if (needsValidateOnFinish()) {
+			validateOnFinishButton = new Button(compositeContainer, SWT.CHECK);
+			validateOnFinishButton.setText(Messages.AbstractRepositorySettingsPage_Validate_on_Finish);
+			validateOnFinishButton.setSelection(true);
+		}
 		Dialog.applyDialogFont(compositeContainer);
 		setControl(compositeContainer);
 	}
@@ -561,7 +577,7 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 					String accountCreationUrl = TasksUiPlugin.getConnectorUi(connector.getConnectorKind())
 							.getAccountCreationUrl(repository);
 					if (accountCreationUrl != null) {
-						WorkbenchUtil.openUrl(accountCreationUrl, IWorkbenchBrowserSupport.AS_EXTERNAL);
+						BrowserUtil.openUrl(accountCreationUrl, IWorkbenchBrowserSupport.AS_EXTERNAL);
 					}
 				}
 			}
@@ -581,7 +597,7 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 					String accountManagementUrl = TasksUiPlugin.getConnectorUi(connector.getConnectorKind())
 							.getAccountManagementUrl(repository);
 					if (accountManagementUrl != null) {
-						WorkbenchUtil.openUrl(accountManagementUrl, IWorkbenchBrowserSupport.AS_EXTERNAL);
+						BrowserUtil.openUrl(accountManagementUrl, IWorkbenchBrowserSupport.AS_EXTERNAL);
 					}
 				}
 			}
@@ -1302,7 +1318,17 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 	/**
 	 * @since 2.0
 	 */
-	protected abstract boolean isValidUrl(String url);
+	protected boolean isValidUrl(String url) {
+		if (url.startsWith(URL_PREFIX_HTTPS) || url.startsWith(URL_PREFIX_HTTP)) {
+			try {
+				new URI(url, true, "UTF-8"); //$NON-NLS-1$
+				return true;
+			} catch (Exception e) {
+				return false;
+			}
+		}
+		return false;
+	}
 
 	private void updateHyperlinks() {
 		if (getRepositoryUrl() != null && getRepositoryUrl().length() > 0) {
@@ -1906,8 +1932,10 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 				}
 			});
 		} catch (InvocationTargetException e) {
-			StatusHandler.fail(new Status(IStatus.ERROR, TasksUiPlugin.ID_PLUGIN,
-					Messages.AbstractRepositorySettingsPage_Internal_error_validating_repository, e.getCause()));
+			StatusManager.getManager().handle(
+					new Status(IStatus.ERROR, TasksUiPlugin.ID_PLUGIN,
+							Messages.AbstractRepositorySettingsPage_Internal_error_validating_repository, e),
+					StatusManager.SHOW | StatusManager.LOG);
 			return;
 		} catch (InterruptedException e) {
 			// canceled
@@ -1957,6 +1985,8 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 			break;
 		}
 		setErrorMessage(null);
+
+		isValid = status.getSeverity() == IStatus.OK || status.getSeverity() == IStatus.INFO;
 	}
 
 	/**
@@ -1985,4 +2015,58 @@ public abstract class AbstractRepositorySettingsPage extends AbstractTaskReposit
 
 	}
 
+	/**
+	 * Provides an adapter for the {@link IValidatable} interface.
+	 * 
+	 * @since 3.7
+	 * @see IAdaptable#getAdapter(Class)
+	 */
+	public Object getAdapter(@SuppressWarnings("rawtypes")
+	Class adapter) {
+		if (adapter == IValidatable.class) {
+			return new IValidatable() {
+				public void validate() {
+					AbstractRepositorySettingsPage.this.validateSettings();
+				}
+
+				public boolean needsValidation() {
+					return AbstractRepositorySettingsPage.this.needsValidation();
+				}
+
+				public boolean canValidate() {
+					return AbstractRepositorySettingsPage.this.canValidate();
+				}
+			};
+		}
+		return null;
+	}
+
+	/**
+	 * @since 3.7
+	 */
+	public boolean needsValidateOnFinish() {
+		return needsValidateOnFinish;
+	}
+
+	/**
+	 * @since 3.7
+	 */
+	public void setNeedsValidateOnFinish(boolean needsValidateOnFinish) {
+		this.needsValidateOnFinish = needsValidateOnFinish;
+	}
+
+	@Override
+	public boolean preFinish(TaskRepository repository) {
+		if (validateOnFinishButton != null && validateOnFinishButton.getSelection()) {
+			isValid = false;
+			validateSettings();
+		} else {
+			isValid = true;
+		}
+		if (isValid) {
+			isValid = super.preFinish(repository);
+		}
+		return isValid;
+	}
+
 }
